@@ -32,7 +32,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: count.c,v 1.2 2007/07/11 09:04:23 roland Exp $
+ *	$Id: count.c,v 1.3 2008/04/19 14:12:49 ldv Exp $
  */
 
 #include "defs.h"
@@ -164,9 +164,14 @@ call_summary_pers(FILE *outf)
 	double  percent;
 	char   *dashes = "-------------------------";
 	char    error_str[16];
-
 	int    *sorted_count = calloc(sizeof(int), nsyscalls);
 
+	if (!sorted_count)
+	{
+		fprintf(stderr, "strace: out of memory for call summary\n");
+		return;
+	}
+
 	call_cum = error_cum = tv_cum.tv_sec = tv_cum.tv_usec = 0;
 	if (overhead.tv_sec == -1)
 	{
