@@ -27,7 +27,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: desc.c,v 1.30 2007/08/02 01:32:17 roland Exp $
+ *	$Id: desc.c,v 1.33 2007/11/01 21:52:20 roland Exp $
  */
 
 #include "defs.h"
@@ -242,28 +242,6 @@ int getlk;
 }
 #endif
 
-static const char *
-sprintflags(const struct xlat *xlat, int flags)
-{
-	static char outstr[1024];
-	const char *sep;
-
-	strcpy(outstr, "flags ");
-	sep = "";
-	for (; xlat->str; xlat++) {
-		if ((flags & xlat->val) == xlat->val) {
-			sprintf(outstr + strlen(outstr),
-				"%s%s", sep, xlat->str);
-			sep = "|";
-			flags &= ~xlat->val;
-		}
-	}
-	if (flags)
-		sprintf(outstr + strlen(outstr),
-			"%s%#x", sep, flags);
-	return outstr;
-}
-
 /*
  * low bits of the open(2) flags define access mode,
  * other bits are real flags.
@@ -356,7 +334,8 @@ sys_fcntl(struct tcb *tcp)
 		case F_GETFD:
 			if (tcp->u_rval == 0)
 				return 0;
-			tcp->auxstr = sprintflags(fdflags, tcp->u_rval);
+			tcp->auxstr =
+				sprintflags("flags ", fdflags, tcp->u_rval);
 			return RVAL_HEX|RVAL_STR;
 		case F_GETFL:
 			tcp->auxstr = sprint_open_modes(tcp->u_rval);
@@ -837,8 +816,7 @@ struct tcb *tcp;
 }
 
 int
-sys_io_getevents(tcp)
-struct tcb *tcp;
+sys_io_getevents(struct tcb * tcp)
 {
 	if (entering(tcp)) {
 		tprintf("%ld, %ld, %ld, ", tcp->u_arg[0], tcp->u_arg[1],
@@ -872,15 +850,7 @@ struct tcb *tcp;
 #endif
 		}
 
-		if (tcp->u_arg[4] == 0)
-			tprintf("NULL");
-		else {
-			struct timespec to;
-			if (umove(tcp, tcp->u_arg[4], &to) == 0)
-				tprintf("{%lu, %lu}", to.tv_sec, to.tv_nsec);
-			else
-				tprintf("{...}");
-		}
+		print_timespec(tcp, tcp->u_arg[4]);
 	}
 	return 0;
 }
@@ -898,7 +868,7 @@ int
 sys_pselect6(struct tcb *tcp)
 {
 	int rc = decode_select(tcp, tcp->u_arg, BITNESS_CURRENT);
-	if (exiting(tcp)) {
+	if (entering(tcp)) {
 		struct {
 			void *ss;
 			unsigned long len;
@@ -907,7 +877,7 @@ sys_pselect6(struct tcb *tcp)
 			tprintf(", %#lx", tcp->u_arg[5]);
 		else {
 			tprintf(", {");
-			if (data.len < sizeof(sigset_t))
+			if (data.len < sizeof(long))
 				tprintf("%#lx", (long)data.ss);
 			else
 				print_sigset(tcp, (long)data.ss, 0);
