@@ -28,21 +28,22 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: file.c,v 1.84 2007/07/24 01:57:11 roland Exp $
+ *	$Id: file.c,v 1.93 2008/08/01 01:13:10 roland Exp $
  */
 
 #include "defs.h"
 
 #include <dirent.h>
+
 #ifdef LINUX
-#define dirent kernel_dirent
-#define dirent64 kernel_dirent64
-#include <linux/types.h>
-#include <linux/dirent.h>
-#undef dirent
-#undef dirent64
+struct kernel_dirent {
+	unsigned long   d_ino;
+	unsigned long   d_off;
+	unsigned short  d_reclen;
+	char            d_name[1];
+};
 #else
-#define kernel_dirent dirent
+# define kernel_dirent dirent
 #endif
 
 #ifdef LINUX
@@ -269,6 +270,9 @@ const struct xlat open_mode_flags[] = {
 #ifdef O_NOATIME
 	{ O_NOATIME, 	"O_NOATIME"	},
 #endif
+#ifdef O_CLOEXEC
+	{ O_CLOEXEC,	"O_CLOEXEC"	},
+#endif
 
 #ifdef FNDELAY
 	{ FNDELAY,	"FNDELAY"	},
@@ -494,6 +498,27 @@ static const struct xlat whence[] = {
 };
 
 #ifndef HAVE_LONG_LONG_OFF_T
+#if defined (LINUX_MIPSN32)
+int
+sys_lseek(tcp)
+struct tcb *tcp;
+{
+	long long offset;
+	int _whence;
+
+	if (entering(tcp)) {
+		tprintf("%ld, ", tcp->u_arg[0]);
+		offset = tcp->ext_arg[1];
+		_whence = tcp->u_arg[2];
+		if (_whence == SEEK_SET)
+			tprintf("%llu, ", offset);
+		else
+			tprintf("%lld, ", offset);
+		printxval(whence, _whence, "SEEK_???");
+	}
+	return RVAL_UDECIMAL;
+}
+#else /* !LINUX_MIPSN32 */
 int
 sys_lseek(tcp)
 struct tcb *tcp;
@@ -513,6 +538,7 @@ struct tcb *tcp;
 	}
 	return RVAL_UDECIMAL;
 }
+#endif /* LINUX_MIPSN32 */
 #endif
 
 #ifdef LINUX
@@ -552,7 +578,9 @@ struct tcb *tcp;
 {
     if (entering(tcp)) {
 	tprintf("%ld, %lld, %ld", tcp->u_arg[0],
-# if defined IA64 || defined X86_64 || defined ALPHA
+# if defined LINUX_MIPSN32
+		tcp->ext_arg[1], tcp->u_arg[2]
+# elif defined IA64 || defined X86_64 || defined ALPHA || defined LINUX_MIPSN64
 		(long long int) tcp->u_arg[1], tcp->u_arg[2]
 # else
 		LONG_LONG(tcp->u_arg[1], tcp->u_arg[2]), tcp->u_arg[3]
@@ -673,20 +701,22 @@ int mode;
 }
 
 static char *
-sprinttime(t)
-time_t t;
+sprinttime(time_t t)
 {
 	struct tm *tmp;
 	static char buf[32];
 
 	if (t == 0) {
-		sprintf(buf, "0");
+		strcpy(buf, "0");
 		return buf;
 	}
-	tmp = localtime(&t);
-	sprintf(buf, "%02d/%02d/%02d-%02d:%02d:%02d",
-		tmp->tm_year + 1900, tmp->tm_mon + 1, tmp->tm_mday,
-		tmp->tm_hour, tmp->tm_min, tmp->tm_sec);
+	if ((tmp = localtime(&t)))
+		snprintf(buf, sizeof buf, "%02d/%02d/%02d-%02d:%02d:%02d",
+			tmp->tm_year + 1900, tmp->tm_mon + 1, tmp->tm_mday,
+			tmp->tm_hour, tmp->tm_min, tmp->tm_sec);
+	else
+		snprintf(buf, sizeof buf, "%lu", (unsigned long) t);
+
 	return buf;
 }
 
@@ -718,9 +748,7 @@ struct solstat {
 };
 
 static void
-printstatsol(tcp, addr)
-struct tcb *tcp;
-long addr;
+printstatsol(struct tcb *tcp, long addr)
 {
 	struct solstat statbuf;
 
@@ -762,9 +790,9 @@ long addr;
 		break;
 	}
 	if (!abbrev(tcp)) {
-		tprintf("st_atime=%s, ", sprinttime(statbuf.st_atime));
-		tprintf("st_mtime=%s, ", sprinttime(statbuf.st_mtime));
-		tprintf("st_ctime=%s}", sprinttime(statbuf.st_ctime));
+		tprintf("st_atime=%s, ", sprinttime(statbuf.st_atime.tv_sec));
+		tprintf("st_mtime=%s, ", sprinttime(statbuf.st_mtime.tv_sec));
+		tprintf("st_ctime=%s}", sprinttime(statbuf.st_ctime.tv_sec));
 	}
 	else
 		tprintf("...}");
@@ -983,6 +1011,38 @@ long addr;
 }
 #endif	/* !HAVE_LONG_LONG_OFF_T */
 
+#if !defined HAVE_STAT64 && defined LINUX && defined X86_64
+/*
+ * Linux x86_64 has unified `struct stat' but its i386 biarch needs
+ * `struct stat64'.  Its <asm-i386/stat.h> definition expects 32-bit `long'.
+ * <linux/include/asm-x86_64/ia32.h> is not in the public includes set.
+ * __GNUC__ is needed for the required __attribute__ below.
+ */
+struct stat64 {
+	unsigned long long	st_dev;
+	unsigned char	__pad0[4];
+	unsigned int	__st_ino;
+	unsigned int	st_mode;
+	unsigned int	st_nlink;
+	unsigned int	st_uid;
+	unsigned int	st_gid;
+	unsigned long long	st_rdev;
+	unsigned char	__pad3[4];
+	long long	st_size;
+	unsigned int	st_blksize;
+	unsigned long long	st_blocks;
+	unsigned int	st_atime;
+	unsigned int	st_atime_nsec;
+	unsigned int	st_mtime;
+	unsigned int	st_mtime_nsec;
+	unsigned int	st_ctime;
+	unsigned int	st_ctime_nsec;
+	unsigned long long	st_ino;
+} __attribute__((packed));
+# define HAVE_STAT64	1
+# define STAT64_SIZE	96
+#endif
+
 #ifdef HAVE_STAT64
 static void
 printstat64(tcp, addr)
@@ -991,6 +1051,10 @@ long addr;
 {
 	struct stat64 statbuf;
 
+#ifdef	STAT64_SIZE
+	(void) sizeof(char[sizeof statbuf == STAT64_SIZE ? 1 : -1]);
+#endif
+
 #ifdef LINUXSPARC
  	if (current_personality == 1) {
  		printstatsol(tcp, addr);
@@ -1058,7 +1122,11 @@ long addr;
 #endif /* !HAVE_STRUCT_STAT_ST_RDEV */
 		break;
 	default:
-		tprintf("st_size=%llu, ", statbuf.st_size);
+#ifdef HAVE_LONG_LONG
+		tprintf("st_size=%llu, ", (unsigned long long) statbuf.st_size);
+#else
+		tprintf("st_size=%lu, ", (unsigned long) statbuf.st_size);
+#endif
 		break;
 	}
 	if (!abbrev(tcp)) {
@@ -2107,7 +2175,7 @@ decode_utimes(struct tcb *tcp, int offset, int special)
 			printtv_bitness(tcp, tcp->u_arg[offset + 1],
 					BITNESS_CURRENT, special);
 			tprintf(", ");
-			printtv_bitness(tcp, tcp->u_arg[offset + 1]	
+			printtv_bitness(tcp, tcp->u_arg[offset + 1]
 					+ sizeof (struct timeval),
 					BITNESS_CURRENT, special);
 			tprintf("}");
@@ -2307,8 +2375,7 @@ static const struct xlat direnttypes[] = {
 #endif
 
 int
-sys_getdents(tcp)
-struct tcb *tcp;
+sys_getdents(struct tcb *tcp)
 {
 	int i, len, dents = 0;
 	char *buf;
@@ -2391,8 +2458,7 @@ struct tcb *tcp;
 
 #if _LFS64_LARGEFILE
 int
-sys_getdents64(tcp)
-struct tcb *tcp;
+sys_getdents64(struct tcb *tcp)
 {
 	int i, len, dents = 0;
 	char *buf;
@@ -2444,6 +2510,10 @@ struct tcb *tcp;
 				d->d_namlen, d->d_namlen, d->d_name);
 		}
 #endif /* SUNOS4 */
+		if (!d->d_reclen) {
+			tprintf("/* d_reclen == 0, problem here */");
+			break;
+		}
 		i += d->d_reclen;
 		dents++;
 	}
@@ -2459,8 +2529,7 @@ struct tcb *tcp;
 
 #ifdef FREEBSD
 int
-sys_getdirentries(tcp)
-struct tcb * tcp;
+sys_getdirentries(struct tcb *tcp)
 {
 	int i, len, dents = 0;
 	long basep;
@@ -2496,6 +2565,10 @@ struct tcb * tcp;
 			tprintf(", d_namlen=%u, d_name=\"%.*s\"}",
 				d->d_namlen, d->d_namlen, d->d_name);
 		}
+		if (!d->d_reclen) {
+			tprintf("/* d_reclen == 0, problem here */");
+			break;
+		}
 		i += d->d_reclen;
 		dents++;
 	}
@@ -2822,7 +2895,10 @@ struct tcb *tcp;
     if (entering(tcp)) {
 	tprintf("%ld, %lld, %lld, ",
 		tcp->u_arg[0],
-# if defined IA64 || defined X86_64 || defined ALPHA
+#if defined LINUX_MIPSN32
+		tcp->ext_arg[1], tcp->ext_arg[2]);
+	printxval(advise, tcp->u_arg[3], "POSIX_FADV_???");
+#elif defined IA64 || defined X86_64 || defined ALPHA || defined LINUX_MIPSN64
 		(long long int) tcp->u_arg[1], (long long int) tcp->u_arg[2]);
 	printxval(advise, tcp->u_arg[3], "POSIX_FADV_???");
 #else
@@ -2878,4 +2954,18 @@ sys_inotify_rm_watch(struct tcb *tcp)
 	}
 	return 0;
 }
+
+int
+sys_fallocate(struct tcb *tcp)
+{
+	if (entering(tcp)) {
+		tprintf("%ld, ", tcp->u_arg[0]);	/* fd */
+		tprintf("%#lo, ", tcp->u_arg[1]);	/* mode */
+		tprintf("%llu, ", LONG_LONG(tcp->u_arg[2],
+			tcp->u_arg[3]));		/* offset */
+		tprintf("%llu", LONG_LONG(tcp->u_arg[4],
+			tcp->u_arg[5]));		/* len */
+	}
+	return 0;
+}
 #endif
