@@ -27,7 +27,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: io.c,v 1.21 2006/12/13 17:08:08 ldv Exp $
+ *	$Id: io.c,v 1.22 2008/05/20 01:11:56 roland Exp $
  */
 
 #include "defs.h"
@@ -360,8 +360,12 @@ struct tcb *tcp;
 			tprintf("%#lx", tcp->u_arg[1]);
 		else
 			printstr(tcp, tcp->u_arg[1], tcp->u_rval);
+#ifdef MIPS_LINUXN32
+		tprintf(", %lu, %#llx", tcp->u_arg[2], tcp->ext_arg[3]);
+#else
 		tprintf(", %lu, %#llx", tcp->u_arg[2],
 			LONG_LONG(tcp->u_arg[3], tcp->u_arg[4]));
+#endif
 	}
 	return 0;
 }
@@ -374,8 +378,12 @@ struct tcb *tcp;
 		ALIGN64 (tcp, 3);
 		tprintf("%ld, ", tcp->u_arg[0]);
 		printstr(tcp, tcp->u_arg[1], tcp->u_arg[2]);
+#ifdef MIPS_LINUXN32
+		tprintf(", %lu, %#llx", tcp->u_arg[2], tcp->ext_arg[3]);
+#else
 		tprintf(", %lu, %#llx", tcp->u_arg[2],
 			LONG_LONG(tcp->u_arg[3], tcp->u_arg[4]));
+#endif
 	}
 	return 0;
 }
