@@ -25,7 +25,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscallent.h,v 1.20 2007/07/05 19:28:35 roland Exp $
+ *	$Id: syscallent.h,v 1.22 2008/07/18 01:23:49 roland Exp $
  */
 
 	{ 6,	0,	printargs,		"osf_syscall"		}, /* 0, not implemented */
@@ -103,7 +103,7 @@
 	{ 5,	0,	printargs,		"osf_old_vadvise"	}, /* 72, not implemented */
 	{ 2,	0,	sys_munmap,		"munmap"		}, /* 73 */
 	{ 3,	0,	sys_mprotect,		"mprotect"		}, /* 74 */
-	{ 0,	0,	sys_madvise,		"madvise"		}, /* 75 */
+	{ 3,	0,	sys_madvise,		"madvise"		}, /* 75 */
 	{ 0,	0,	sys_vhangup,		"vhangup"		}, /* 76 */
 	{ 5,	0,	printargs,		"osf_kmodcall"		}, /* 77, not implemented */
 	{ 5,	0,	printargs,		"osf_mincore"		}, /* 78, not implemented */
@@ -399,13 +399,13 @@
 	{ 2,	0,	sys_capget,		"capget"		}, /* 368 */
 	{ 2,	0,	sys_capset,		"capset"		}, /* 369 */
 	{ 4,	TD,	sys_sendfile,		"sendfile"		}, /* 370 */
-	{ 3,	0,	printargs,		"setresgid"		}, /* 371 */
-	{ 3,	0,	printargs,		"getresgid"		}, /* 372 */
+	{ 3,	0,	sys_setresgid,		"setresgid"		}, /* 371 */
+	{ 3,	0,	sys_getresgid,		"getresgid"		}, /* 372 */
 	{ 4,	0,	printargs,		"dipc"			}, /* 373, not implemented */
-	{ 2,	TF,	printargs,		"pivot_root"		}, /* 374 */
-	{ 3,	0,	printargs,		"mincore"		}, /* 375 */
-	{ 4,	0,	printargs,		"pciconfig_iobase"	}, /* 376 */
-	{ 4,	TD,	sys_getdents64,		"getdents64"		}, /* 377 */
+	{ 2,	TF,	sys_pivotroot,		"pivot_root"		}, /* 374 */
+	{ 3,	0,	sys_mincore,		"mincore"		}, /* 375 */
+	{ 3,	0,	printargs,		"pciconfig_iobase"	}, /* 376 */
+	{ 3,	TD,	sys_getdents64,		"getdents64"		}, /* 377 */
 	{ 0,	0,	printargs,		"gettid"		}, /* 378 */
 	{ 4,	TD,	sys_readahead,		"readahead"		}, /* 379 */
 	{ 5,	0,	printargs,		"SYS_380"		}, /* 380 */
@@ -422,7 +422,7 @@
 	{ 2,	TF,	sys_removexattr,	"removexattr"		}, /* 391 */
 	{ 2,	TF,	sys_removexattr,	"lremovexattr"		}, /* 392 */
 	{ 2,	TD,	sys_fremovexattr,	"fremovexattr"		}, /* 393 */
-	{ 5,	0,	sys_futex,		"futex"			}, /* 394 */
+	{ 6,	0,	sys_futex,		"futex"			}, /* 394 */
 	{ 3,	0,	sys_sched_setaffinity,	"sched_setaffinity"	}, /* 395 */
 	{ 3,	0,	sys_sched_getaffinity,	"sched_getaffinity"	}, /* 396 */
 	{ 5,	0,	printargs,		"tuxcall"		}, /* 397 */
