@@ -25,7 +25,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscallent.h,v 1.5 2007/07/24 01:53:01 roland Exp $
+ *	$Id: syscallent.h,v 1.7 2008/07/18 01:23:49 roland Exp $
  */
 
 	{ 0,	0,	sys_restart_syscall,	"restart_syscall" }, /* 0 */
@@ -248,7 +248,7 @@
 	{ 2,	TF,	sys_pivotroot,		"pivot_root"	}, /* 217 */
 	{ 5,	0,	printargs,		"SYS_218"	}, /* 218 */
 	{ 5,	0,	printargs,		"SYS_219"	}, /* 219 */
-	{ 4,	0,	sys_getdents64,		"getdents64"	}, /* 220 */
+	{ 3,	TD,	sys_getdents64,		"getdents64"	}, /* 220 */
 	{ 0,	0,	printargs,		"gettid"	}, /* 221 */
 	{ 2,	TS,	sys_kill,		"tkill"		}, /* 222 */
 	{ 5,	TF,	sys_setxattr,		"setxattr"	}, /* 223 */
@@ -263,7 +263,7 @@
 	{ 2,	TF,	sys_removexattr,	"removexattr"	}, /* 232 */
 	{ 2,	TF,	sys_removexattr,	"lremovexattr"	}, /* 233 */
 	{ 2,	0,	sys_fremovexattr,	"fremovexattr"	}, /* 234 */
-	{ 5,	0,	sys_futex,		"futex"		}, /* 235 */
+	{ 6,	0,	sys_futex,		"futex"		}, /* 235 */
 	{ 4,	TF,	sys_sendfile64,		"sendfile64"	}, /* 236 */
 	{ 3,	0,	sys_mincore,		"mincore"	}, /* 237 */
 	{ 3,	0,	sys_madvise,		"madvise"	}, /* 238 */
