@@ -25,7 +25,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscallent.h,v 1.32 2007/08/02 01:44:14 roland Exp $
+ *	$Id: syscallent.h,v 1.35 2008/08/25 03:09:16 roland Exp $
  */
 
 	{ 0,	0,	sys_restart_syscall,	"restart_syscall"	}, /* 0 */
@@ -250,7 +250,7 @@
 	{ 2,	TF,	sys_removexattr,	"removexattr"		}, /* 218 */
 	{ 2,	TF,	sys_removexattr,	"lremovexattr"		}, /* 219 */
 	{ 2,	TD,	sys_fremovexattr,	"fremovexattr"		}, /* 220 */
-	{ 5,	0,	sys_futex,		"futex"			}, /* 221 */
+	{ 6,	0,	sys_futex,		"futex"			}, /* 221 */
 	{ 3,	0,	sys_sched_setaffinity,	"sched_setaffinity"	}, /* 222 */
 	{ 3,	0,	sys_sched_getaffinity,	"sched_getaffinity"	}, /* 223 */
 	{ 5,	0,	printargs,		"SYS_224"		}, /* 224 */
@@ -299,7 +299,7 @@
 	{ 3,	0,	sys_mq_getsetattr,	"mq_getsetattr"		}, /* 267 */
 	{ 5,	0,	printargs,		"sys_kexec_load"	}, /* 268 */
 	{ 5,	0,	printargs,		"add_key"		}, /* 269 */
-	{ 5,	0,	printargs,		"request_key"		}, /* 270 */
+	{ 4,	0,	printargs,		"request_key"		}, /* 270 */
 	{ 5,	0,	printargs,		"keyctl"		}, /* 271 */
 	{ 5,	TP,	sys_waitid,		"waitid"		}, /* 272 */
 	{ 3,	0,	printargs,		"ioprio_set"		}, /* 273 */
@@ -339,7 +339,7 @@
 	{ 1,	TD,	sys_eventfd,		"eventfd"		}, /* 307 */
 	{ 5,	0,	printargs,		"SYS_308"		}, /* 308 */
 	{ 5,	0,	printargs,		"SYS_309"		}, /* 309 */
-	{ 5,	0,	printargs,		"SYS_310"		}, /* 310 */
+	{ 3,    0,      sys_subpage_prot,       "subpage_prot"          }, /* 310 */
 	{ 5,	0,	printargs,		"SYS_311"		}, /* 311 */
 	{ 5,	0,	printargs,		"SYS_312"		}, /* 312 */
 	{ 5,	0,	printargs,		"SYS_313"		}, /* 313 */
