@@ -25,10 +25,11 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscall.h,v 1.8 2004/03/02 06:08:55 roland Exp $
+ *	$Id: syscall.h,v 1.13 2008/05/19 23:50:24 roland Exp $
  */
 #include "dummy.h"
 
+int	sys_restart_syscall();
 int	sys_nosys();
 int	sys_nullsys();
 int	sys_errsys();
@@ -59,6 +60,7 @@ int	sys_getitimer(),sys_setitimer();
 /* 1.5 descriptors */
 int	sys_getdtablesize(),sys_dup(),sys_dup2(),sys_close();
 int	sys_oldselect(),sys_select(),sys_getdopt(),sys_setdopt(),sys_fcntl(),sys_flock();
+int	sys_epoll_create(), sys_epoll_ctl(), sys_epoll_wait();
 
 /* 1.6 resource controls */
 int	sys_getpriority(),sys_setpriority(),sys_getrusage(),sys_getrlimit(),sys_setrlimit();
@@ -90,7 +92,7 @@ int	sys_truncate(),sys_ftruncate(),sys_access(),sys_fsync(),sys_sysctl();
 int	sys_statfs(),sys_fstatfs(),sys_msync();
 int sys_stat64(), sys_lstat64(), sys_fstat64();
 int sys_truncate64(), sys_ftruncate64();
-
+int sys_semtimedop();
 
 /* 2.3 communications */
 int	sys_socket(),sys_bind(),sys_listen(),sys_accept(),sys_connect();
@@ -105,6 +107,7 @@ int sys_rt_sigpending(), sys_rt_sigsuspend(), sys_rt_sigqueueinfo();
 int sys_rt_sigtimedwait(), sys_prctl(), sys_poll();
 int sys_sendfile(), sys_query_module(), sys_capget(), sys_capset();
 int sys_create_module(), sys_init_module();
+int sys_setgroups32(), sys_getgroups32();
 
 int	sys_umask();		/* XXX */
 
@@ -191,4 +194,61 @@ int	sys_poll();
 
 int	sys_vpixsys();		/* VP/ix system calls */
 
+int	sys_sendfile64(), sys_futex(), sys_gettid(), sys_sched_setaffinity();
+int	sys_sched_getaffinity(), sys_setxattr(), sys_lsetxattr();
+int	sys_fsetxattr(), sys_getxattr(), sys_lgetxattr(), sys_fgetxattr();
+int	sys_listxattr(), sys_llistxattr(), sys_flistxattr();
+int	sys_removexattr(), sys_lremovexattr(), sys_fremovexattr();
+int	sys_remap_file_pages(), sys_readahead(), sys_tgkill(), sys_statfs64();
+int	sys_fstatfs64(), sys_clock_settime(), sys_clock_gettime();
+int	sys_clock_getres(), sys_clock_nanosleep();
+int	sys_timer_create(), sys_timer_settime(), sys_timer_gettime();
+
+int	sys_io_setup(), sys_io_destroy(), sys_io_submit(), sys_io_cancel(), sys_io_getevents();
+int	sys_mq_open(), sys_mq_unlink(), sys_mq_timedsend(), sys_mq_timedreceive(), sys_mq_notify(), sys_mq_getsetattr();
+int	sys_waitid();
+int	sys_openat(), sys_mkdirat(), sys_mknodat(), sys_fchownat(), sys_futimesat(), sys_newfstatat(), sys_unlinkat(), sys_renameat(), sys_linkat(), sys_symlinkat(), sys_readlinkat(), sys_fchmodat(),	sys_faccessat();
+int	sys_pselect6(), sys_ppoll();
+int	sys_unshare();
+int	sys_move_pages(), sys_getcpu();
+int	sys_epoll_pwait();
+int	sys_signalfd(), sys_timerfd(), sys_eventfd();
+
+#  define SYS_socket_subcall	353
+#define SYS_sub_socket		(SYS_socket_subcall + 1)
+#define SYS_sub_bind		(SYS_socket_subcall + 2)
+#define SYS_sub_connect		(SYS_socket_subcall + 3)
+#define SYS_sub_listen		(SYS_socket_subcall + 4)
+#define SYS_sub_accept		(SYS_socket_subcall + 5)
+#define SYS_sub_getsockname	(SYS_socket_subcall + 6)
+#define SYS_sub_getpeername	(SYS_socket_subcall + 7)
+#define SYS_sub_socketpair	(SYS_socket_subcall + 8)
+#define SYS_sub_send		(SYS_socket_subcall + 9)
+#define SYS_sub_recv		(SYS_socket_subcall + 10)
+#define SYS_sub_sendto		(SYS_socket_subcall + 11)
+#define SYS_sub_recvfrom	(SYS_socket_subcall + 12)
+#define SYS_sub_shutdown	(SYS_socket_subcall + 13)
+#define SYS_sub_setsockopt	(SYS_socket_subcall + 14)
+#define SYS_sub_getsockopt	(SYS_socket_subcall + 15)
+#define SYS_sub_sendmsg		(SYS_socket_subcall + 16)
+#define SYS_sub_recvmsg		(SYS_socket_subcall + 17)
+
+#define SYS_socket_nsubcalls	18
+
+#define SYS_ipc_subcall		((SYS_socket_subcall)+(SYS_socket_nsubcalls))
+#define SYS_sub_semop		(SYS_ipc_subcall + 1)
+#define SYS_sub_semget		(SYS_ipc_subcall + 2)
+#define SYS_sub_semctl		(SYS_ipc_subcall + 3)
+#define SYS_sub_semtimedop	(SYS_ipc_subcall + 4)
+#define SYS_sub_msgsnd		(SYS_ipc_subcall + 11)
+#define SYS_sub_msgrcv		(SYS_ipc_subcall + 12)
+#define SYS_sub_msgget		(SYS_ipc_subcall + 13)
+#define SYS_sub_msgctl		(SYS_ipc_subcall + 14)
+#define SYS_sub_shmat		(SYS_ipc_subcall + 21)
+#define SYS_sub_shmdt		(SYS_ipc_subcall + 22)
+#define SYS_sub_shmget		(SYS_ipc_subcall + 23)
+#define SYS_sub_shmctl		(SYS_ipc_subcall + 24)
+
+#define SYS_ipc_nsubcalls	25
+
 #include "syscall1.h"
