@@ -80,7 +80,7 @@
 	{ 2,	0,	sys_getgroups,	"getgroups" },		/* 79 */
 	{ 2,	0,	sys_setgroups,	"setgroups" },		/* 80 */
 	{ 0,	0,	sys_getpgrp,	"getpgrp" },		/* 81 */
-	{ 2,	0,	sys_setgroups,	"setgroups32" },	/* 82 */
+	{ 2,	0,	sys_setgroups32,"setgroups32" },	/* 82 */
 	{ 3,	0,	sys_setitimer,	"setitimer" },		/* 83 */
 	{ 2,	TD,	sys_ftruncate,	"ftruncate64" },	/* 84 */
 	{ 1,	TF,	sys_swapon,	"swapon" },		/* 85 */
@@ -113,7 +113,7 @@
 	{ 2,	TS,	sys_setresgid,	"setresgid32" },	/* 112 */
 	{ 5,	TN,	sys_recvmsg,	"recvmsg" },		/* 113 */
 	{ 5,	TN,	sys_sendmsg,	"sendmsg" },		/* 114 */
-	{ 2,	0,	sys_getgroups,	"getgroups32" },	/* 115 */
+	{ 2,	0,	sys_getgroups32,"getgroups32" },	/* 115 */
 	{ 2,	0,	sys_gettimeofday,"gettimeofday" },	/* 116 */
 	{ 2,	0,	sys_getrusage,	"getrusage" },		/* 117 */
 	{ 5,	TN,	sys_getsockopt,	"getsockopt" },		/* 118 */
@@ -140,7 +140,7 @@
 	{ 2,	TF,	sys_stat64,	"stat64" },		/* 139 */
 	{ 4,    TD,	sys_sendfile64,	"sendfile64" },		/* 140 */
 	{ 3,	TN,	sys_getpeername,"getpeername" },	/* 141 */
-	{ 5,    0,	sys_futex,	"futex" },		/* 142 */
+	{ 6,    0,	sys_futex,	"futex" },		/* 142 */
 	{ 0,	0,	printargs,	"gettid" },		/* 143 */
 	{ 2,	0,	sys_getrlimit,	"getrlimit" },		/* 144 */
 	{ 2,	0,	sys_setrlimit,	"setrlimit" },		/* 145 */
@@ -152,7 +152,7 @@
 	{ 4,	TN,	sys_getmsg,	"getmsg" },		/* 151 */
 	{ 4,	TN,	sys_putmsg,	"putmsg" },		/* 152 */
 	{ 3,	TD,	sys_poll,	"poll" },		/* 153 */
-	{ 4,	TD,	sys_getdents64,	"getdents64" },		/* 154 */
+	{ 3,	TD,	sys_getdents64,	"getdents64" },		/* 154 */
 	{ 3,	TD,	sys_fcntl,	"fcntl64" },		/* 155 */
 	{ 4,	0,	printargs,	"getdirentries" },	/* 156 */
 	{ 2,	TF,	sys_statfs,	"statfs" },		/* 157 */
@@ -351,3 +351,57 @@
 	{ 5,	0,	printargs,	"SYS_350" },		/* 350 */
 	{ 5,	0,	printargs,	"SYS_351" },		/* 351 */
 	{ 5,	0,	printargs,	"SYS_352" },		/* 352 */
+#if SYS_socket_subcall != 353
+ #error fix me
+#endif
+	{ 8,	0,	printargs,		"socket_subcall"}, /* 353 */
+	{ 3,	TN,	sys_socket,		"socket"	}, /* 354 */
+	{ 3,	TN,	sys_bind,		"bind"		}, /* 355 */
+	{ 3,	TN,	sys_connect,		"connect"	}, /* 356 */
+	{ 2,	TN,	sys_listen,		"listen"	}, /* 357 */
+	{ 3,	TN,	sys_accept,		"accept"	}, /* 358 */
+	{ 3,	TN,	sys_getsockname,	"getsockname"	}, /* 359 */
+	{ 3,	TN,	sys_getpeername,	"getpeername"	}, /* 360 */
+	{ 4,	TN,	sys_socketpair,		"socketpair"	}, /* 361 */
+	{ 4,	TN,	sys_send,		"send"		}, /* 362 */
+	{ 4,	TN,	sys_recv,		"recv"		}, /* 363 */
+	{ 6,	TN,	sys_sendto,		"sendto"	}, /* 364 */
+	{ 6,	TN,	sys_recvfrom,		"recvfrom"	}, /* 365 */
+	{ 2,	TN,	sys_shutdown,		"shutdown"	}, /* 366 */
+	{ 5,	TN,	sys_setsockopt,		"setsockopt"	}, /* 367 */
+	{ 5,	TN,	sys_getsockopt,		"getsockopt"	}, /* 368 */
+	{ 5,	TN,	sys_sendmsg,		"sendmsg"	}, /* 369 */
+	{ 5,	TN,	sys_recvmsg,		"recvmsg"	}, /* 370 */
+#if SYS_ipc_subcall != 371
+ #error fix me
+#endif
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 371 */
+	{ 4,	TI,	printargs,		"semop"		}, /* 372 */
+	{ 4,	TI,	sys_semget,		"semget"	}, /* 373 */
+	{ 4,	TI,	sys_semctl,		"semctl"	}, /* 374 */
+	{ 5,	TI,	sys_semtimedop,		"semtimedop"	}, /* 375 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 376 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 377 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 378 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 379 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 380 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 381 */
+	{ 4,	TI,	sys_msgsnd,		"msgsnd"	}, /* 382 */
+	{ 4,	TI,	sys_msgrcv,		"msgrcv"	}, /* 383 */
+	{ 4,	TI,	sys_msgget,		"msgget"	}, /* 384 */
+	{ 4,	TI,	sys_msgctl,		"msgctl"	}, /* 385 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 386 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 387 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 388 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 389 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 390 */
+	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 391 */
+	{ 4,	TI,	sys_shmat,		"shmat"		}, /* 392 */
+	{ 4,	TI,	sys_shmdt,		"shmdt"		}, /* 393 */
+	{ 4,	TI,	sys_shmget,		"shmget"	}, /* 394 */
+	{ 4,	TI,	sys_shmctl,		"shmctl"	}, /* 395 */
+	{ 5,	0,	printargs,		"SYS_343"	}, /* 396 */
+	{ 5,	0,	printargs,		"SYS_344"	}, /* 397 */
+	{ 5,	0,	printargs,		"SYS_345"	}, /* 398 */
+	{ 5,	0,	printargs,		"SYS_346"	}, /* 399 */
+	{ 5,	0,	printargs,		"SYS_347"	}, /* 400 */
