@@ -200,7 +200,7 @@
 	{ 2,	TD,	sys_fremovexattr,	"fremovexattr"	}, /* 199 */
 	{ 2,	0,	sys_kill,		"tkill"		}, /* 200 */
 	{ 1,	0,	sys_time,		"time"		},  /* 201 */
-	{ 5,	0,	sys_futex,		"futex"		}, /* 202 */
+	{ 6,	0,	sys_futex,		"futex"		}, /* 202 */
 	{ 3,	0,	sys_sched_setaffinity,	"sched_setaffinity" },/* 203 */
 	{ 3,	0,	sys_sched_getaffinity,	"sched_getaffinity" },/* 204 */
 	{ 1,	0,	sys_set_thread_area,	"set_thread_area" }, /* 205 */
@@ -215,7 +215,7 @@
 	{ 4,	0,	printargs,		"epoll_ctl_old"	}, /* 214 */
 	{ 4,	0,	printargs,		"epoll_wait_old"}, /* 215 */
 	{ 5,	0,	sys_remap_file_pages,	"remap_file_pages"}, /* 216 */
-	{ 4,	TD,	sys_getdents64,		"getdents64"	}, /* 217 */
+	{ 3,	TD,	sys_getdents64,		"getdents64"	}, /* 217 */
 	{ 1,	0,	printargs,		"set_tid_address"}, /* 218 */
 	{ 0,	0,	sys_restart_syscall,	"restart_syscall"}, /* 219 */
 	{ 5,	TI,	sys_semtimedop,		"semtimedop"	}, /* 220 */
@@ -281,5 +281,8 @@
 	{ 4,	TD|TF,	sys_utimensat,		"utimensat"	}, /* 280 */
 	{ 5,	TD,	sys_epoll_pwait,	"epoll_pwait"	}, /* 281 */
 	{ 3,	TD|TS,	sys_signalfd,		"signalfd"	}, /* 282 */
-	{ 4,	TD,	sys_timerfd,		"timerfd"	}, /* 283 */
+	{ 2,	TD,	sys_timerfd_create,	"timerfd_create"}, /* 283 */
 	{ 1,	TD,	sys_eventfd,		"eventfd"	}, /* 284 */
+	{ 6,	TF,	sys_fallocate,		"fallocate"	}, /* 285 */
+	{ 4,	TD,	sys_timerfd_settime,	"timerfd_settime"}, /* 286 */
+	{ 2,	TD,	sys_timerfd_gettime,	"timerfd_gettime"}, /* 287 */
