@@ -29,7 +29,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: mem.c,v 1.40 2007/07/24 01:52:58 roland Exp $
+ *	$Id: mem.c,v 1.45 2008/08/25 03:09:16 roland Exp $
  */
 
 #include "defs.h"
@@ -95,6 +95,9 @@ static const struct xlat mmap_prot[] = {
 #endif
 #ifdef PROT_GROWSUP
 	{ PROT_GROWSUP, "PROT_GROWSUP"	},
+#endif
+#ifdef PROT_SAO
+	{ PROT_SAO,	"PROT_SAO"	},
 #endif
 	{ 0,		NULL		},
 };
@@ -191,9 +194,10 @@ static const struct xlat mmap_flags[] = {
 #if !HAVE_LONG_LONG_OFF_T
 static
 int
-print_mmap(tcp,u_arg)
+print_mmap(tcp,u_arg, offset)
 struct tcb *tcp;
 long *u_arg;
+long long offset;
 {
 	if (entering(tcp)) {
 		/* addr */
@@ -216,7 +220,7 @@ long *u_arg;
 		/* fd (is always int, not long) */
 		tprintf(", %d, ", (int)u_arg[4]);
 		/* offset */
-		tprintf("%#lx", u_arg[5]);
+		tprintf("%#llx", offset);
 	}
 	return RVAL_HEX;
 }
@@ -265,7 +269,7 @@ struct tcb *tcp;
     if (umoven(tcp, tcp->u_arg[0], sizeof u_arg, (char *) u_arg) == -1)
 	    return 0;
 #endif	// defined(IA64)
-    return print_mmap(tcp, u_arg);
+    return print_mmap(tcp, u_arg, u_arg[5]);
 
 }
 #endif
@@ -274,6 +278,8 @@ int
 sys_mmap(tcp)
 struct tcb *tcp;
 {
+    long long offset = tcp->u_arg[5];
+
 #if defined(LINUX) && defined(SH64)
     /*
      * Old mmap differs from new mmap in specifying the
@@ -281,9 +287,12 @@ struct tcb *tcp;
      * pretend it's in byte units so the user only ever
      * sees bytes in the printout.
      */
-    tcp->u_arg[5] <<= PAGE_SHIFT;
+    offset <<= PAGE_SHIFT;
 #endif
-    return print_mmap(tcp, tcp->u_arg);
+#if defined(LINUX_MIPSN32)
+    offset = tcp->ext_arg[5];
+#endif
+    return print_mmap(tcp, tcp->u_arg, offset);
 }
 #endif /* !HAVE_LONG_LONG_OFF_T */
 
@@ -378,11 +387,11 @@ struct tcb *tcp;
 	return RVAL_HEX;
 }
 
-static const struct xlat madvise_flags[] = {
+static const struct xlat madvise_cmds[] = {
 #ifdef MADV_NORMAL
 	{ MADV_NORMAL,		"MADV_NORMAL" },
 #endif
-#ifdef MADZV_RANDOM
+#ifdef MADV_RANDOM
 	{ MADV_RANDOM,		"MADV_RANDOM" },
 #endif
 #ifdef MADV_SEQUENTIAL
@@ -391,7 +400,7 @@ static const struct xlat madvise_flags[] = {
 #ifdef MADV_WILLNEED
 	{ MADV_WILLNEED,	"MADV_WILLNEED" },
 #endif
-#ifdef MADV_DONTNED
+#ifdef MADV_DONTNEED
 	{ MADV_DONTNEED,	"MADV_DONTNEED" },
 #endif
 	{ 0,			NULL },
@@ -404,7 +413,7 @@ struct tcb *tcp;
 {
 	if (entering(tcp)) {
 		tprintf("%#lx, %lu, ", tcp->u_arg[0], tcp->u_arg[1]);
-		printflags(madvise_flags, tcp->u_arg[2], "MADV_???");
+		printxval(madvise_cmds, tcp->u_arg[2], "MADV_???");
 	}
 	return 0;
 }
@@ -544,7 +553,7 @@ struct tcb *tcp;
 	return 0;
 }
 
-#if defined(ALPHA) || defined(FREEBSD) || defined(IA64) || defined(SUNOS4) || defined(SVR4)
+#if defined(ALPHA) || defined(FREEBSD) || defined(IA64) || defined(SUNOS4) || defined(SVR4) || defined(SPARC) || defined(SPARC64)
 int
 sys_getpagesize(tcp)
 struct tcb *tcp;
@@ -877,3 +886,53 @@ struct tcb *tcp;
 	return 0;
 }
 #endif
+
+#if defined(LINUX) && defined(POWERPC)
+int
+sys_subpage_prot(tcp)
+struct tcb *tcp;
+{
+	if (entering(tcp)) {
+		unsigned long cur, end, abbrev_end, entries;
+		unsigned int entry;
+
+		tprintf("%#lx, %#lx, ", tcp->u_arg[0], tcp->u_arg[1]);
+		entries = tcp->u_arg[1] >> 16;
+		if (!entries || !tcp->u_arg[2]) {
+			tprintf("{}");
+			return 0;
+		}
+		cur = tcp->u_arg[2];
+		end = cur + (sizeof(int) * entries);
+		if (!verbose(tcp) || end < tcp->u_arg[2]) {
+			tprintf("%#lx", tcp->u_arg[2]);
+			return 0;
+		}
+		if (abbrev(tcp)) {
+			abbrev_end = cur + (sizeof(int) * max_strlen);
+			if (abbrev_end > end)
+				abbrev_end = end;
+		}
+		else
+			abbrev_end = end;
+		tprintf("{");
+		for (; cur < end; cur += sizeof(int)) {
+			if (cur > tcp->u_arg[2])
+				tprintf(", ");
+			if (cur >= abbrev_end) {
+				tprintf("...");
+				break;
+			}
+			if (umove(tcp, cur, &entry) < 0) {
+				tprintf("??? [%#lx]", cur);
+				break;
+			}
+			else
+				tprintf("%#08x", entry);
+		}
+		tprintf("}");
+	}
+
+	return 0;
+}
+#endif
