@@ -34,7 +34,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: process.c,v 1.107 2007/08/02 02:13:05 roland Exp $
+ *	$Id: process.c,v 1.113 2008/07/18 02:16:47 roland Exp $
  */
 
 #include "defs.h"
@@ -215,6 +215,42 @@ static const struct xlat prctl_options[] = {
 #endif
 #ifdef PR_SET_KEEPCAPS
 	{ PR_SET_KEEPCAPS,	"PR_SET_KEEP_CAPS"	},
+#endif
+#ifdef PR_GET_FPEMU
+	{ PR_GET_FPEMU,		"PR_GET_FPEMU"		},
+#endif
+#ifdef PR_SET_FPEMU
+	{ PR_SET_FPEMU,		"PR_SET_FPEMU"		},
+#endif
+#ifdef PR_GET_FPEXC
+	{ PR_GET_FPEXC,		"PR_GET_FPEXC"		},
+#endif
+#ifdef PR_SET_FPEXC
+	{ PR_SET_FPEXC,		"PR_SET_FPEXC"		},
+#endif
+#ifdef PR_GET_TIMING
+	{ PR_GET_TIMING,	"PR_GET_TIMING"		},
+#endif
+#ifdef PR_SET_TIMING
+	{ PR_SET_TIMING,	"PR_SET_TIMING"		},
+#endif
+#ifdef PR_SET_NAME
+	{ PR_SET_NAME,		"PR_SET_NAME"		},
+#endif
+#ifdef PR_GET_NAME
+	{ PR_GET_NAME,		"PR_GET_NAME"		},
+#endif
+#ifdef PR_GET_ENDIAN
+	{ PR_GET_ENDIAN,	"PR_GET_ENDIAN"		},
+#endif
+#ifdef PR_SET_ENDIAN
+	{ PR_SET_ENDIAN,	"PR_SET_ENDIAN"		},
+#endif
+#ifdef PR_GET_SECCOMP
+	{ PR_GET_SECCOMP,	"PR_GET_SECCOMP"	},
+#endif
+#ifdef PR_SET_SECCOMP
+	{ PR_SET_SECCOMP,	"PR_SET_SECCOMP"	},
 #endif
 	{ 0,			NULL			},
 };
@@ -953,8 +989,7 @@ struct tcb *tcp;
 #ifdef SYS_vfork
 	if (known_scno(tcp) == SYS_vfork) {
 		/* Attempt to make vfork into fork, which we can follow. */
-		if (!followvfork ||
-		    change_syscall(tcp, SYS_fork) < 0)
+		if (change_syscall(tcp, SYS_fork) < 0)
 			dont_follow = 1;
 	}
 #endif
@@ -1912,7 +1947,13 @@ int bitness;
 	int exited = 0;
 
 	if (entering(tcp)) {
-		tprintf("%ld, ", tcp->u_arg[0]);
+		/*
+		 * Sign-extend a 32-bit value when that's what it is.
+		 */
+		long pid = tcp->u_arg[0];
+		if (personality_wordsize[current_personality] < sizeof pid)
+			pid = (long) (int) pid;
+		tprintf("%ld, ", pid);
 	} else {
 		/* status */
 		if (!tcp->u_arg[1])
@@ -2889,6 +2930,80 @@ const struct xlat struct_user_offsets[] = {
 	{ uoff(regs.ARM_cpsr),	"cpsr"					},
 #endif
 
+#ifdef MIPS
+	{ 0,			"r0"					},
+	{ 1,			"r1"					},
+	{ 2,			"r2"					},
+	{ 3,			"r3"					},
+	{ 4,			"r4"					},
+	{ 5,			"r5"					},
+	{ 6,			"r6"					},
+	{ 7,			"r7"					},
+	{ 8,			"r8"					},
+	{ 9,			"r9"					},
+	{ 10,			"r10"					},
+	{ 11,			"r11"					},
+	{ 12,			"r12"					},
+	{ 13,			"r13"					},
+	{ 14,			"r14"					},
+	{ 15,			"r15"					},
+	{ 16,			"r16"					},
+	{ 17,			"r17"					},
+	{ 18,			"r18"					},
+	{ 19,			"r19"					},
+	{ 20,			"r20"					},
+	{ 21,			"r21"					},
+	{ 22,			"r22"					},
+	{ 23,			"r23"					},
+	{ 24,			"r24"					},
+	{ 25,			"r25"					},
+	{ 26,			"r26"					},
+	{ 27,			"r27"					},
+	{ 28,			"r28"					},
+	{ 29,			"r29"					},
+	{ 30,			"r30"					},
+	{ 31,			"r31"					},
+	{ 32,			"f0"					},
+	{ 33,			"f1"					},
+	{ 34,			"f2"					},
+	{ 35,			"f3"					},
+	{ 36,			"f4"					},
+	{ 37,			"f5"					},
+	{ 38,			"f6"					},
+	{ 39,			"f7"					},
+	{ 40,			"f8"					},
+	{ 41,			"f9"					},
+	{ 42,			"f10"					},
+	{ 43,			"f11"					},
+	{ 44,			"f12"					},
+	{ 45,			"f13"					},
+	{ 46,			"f14"					},
+	{ 47,			"f15"					},
+	{ 48,			"f16"					},
+	{ 49,			"f17"					},
+	{ 50,			"f18"					},
+	{ 51,			"f19"					},
+	{ 52,			"f20"					},
+	{ 53,			"f21"					},
+	{ 54,			"f22"					},
+	{ 55,			"f23"					},
+	{ 56,			"f24"					},
+	{ 57,			"f25"					},
+	{ 58,			"f26"					},
+	{ 59,			"f27"					},
+	{ 60,			"f28"					},
+	{ 61,			"f29"					},
+	{ 62,			"f30"					},
+	{ 63,			"f31"					},
+	{ 64,			"pc"					},
+	{ 65,			"cause"					},
+	{ 66,			"badvaddr"				},
+	{ 67,			"mmhi"					},
+	{ 68,			"mmlo"					},
+	{ 69,			"fpcsr"					},
+	{ 70,			"fpeir"					},
+#endif
+
 #if !defined(S390) && !defined(S390X) && !defined(MIPS) && !defined(SPARC64)
 	{ uoff(u_fpvalid),	"offsetof(struct user, u_fpvalid)"	},
 #endif
@@ -3022,10 +3137,12 @@ struct tcb *tcp;
 			tprintf("%#lx, ", tcp->u_arg[2]);
 #ifdef LINUX
 		switch (tcp->u_arg[0]) {
+#ifndef IA64
 		case PTRACE_PEEKDATA:
 		case PTRACE_PEEKTEXT:
 		case PTRACE_PEEKUSER:
 			break;
+#endif
 		case PTRACE_CONT:
 		case PTRACE_SINGLESTEP:
 		case PTRACE_SYSCALL:
@@ -3041,8 +3158,12 @@ struct tcb *tcp;
 		case PTRACE_PEEKDATA:
 		case PTRACE_PEEKTEXT:
 		case PTRACE_PEEKUSER:
+#ifdef IA64
+			return RVAL_HEX;
+#else
 			printnum(tcp, tcp->u_arg[3], "%#lx");
 			break;
+#endif
 		}
 	}
 #endif /* LINUX */
@@ -3084,8 +3205,11 @@ struct tcb *tcp;
 #  define FUTEX_UNLOCK_PI 7
 #  define FUTEX_TRYLOCK_PI 8
 # endif
-# ifndef FUTEX_CMP_REQUEUE_PI
-#  define FUTEX_CMP_REQUEUE_PI 9
+# ifndef FUTEX_WAIT_BITSET
+#  define FUTEX_WAIT_BITSET 9
+# endif
+# ifndef FUTEX_WAKE_BITSET
+#  define FUTEX_WAKE_BITSET 10
 # endif
 # ifndef FUTEX_PRIVATE_FLAG
 #  define FUTEX_PRIVATE_FLAG 128
@@ -3100,7 +3224,8 @@ static const struct xlat futexops[] = {
 	{ FUTEX_LOCK_PI,				"FUTEX_LOCK_PI" },
 	{ FUTEX_UNLOCK_PI,				"FUTEX_UNLOCK_PI" },
 	{ FUTEX_TRYLOCK_PI,				"FUTEX_TRYLOCK_PI" },
-	{ FUTEX_CMP_REQUEUE_PI,				"FUTEX_CMP_REQUEUE_PI" },
+	{ FUTEX_WAIT_BITSET,				"FUTEX_WAIT_BITSET" },
+	{ FUTEX_WAKE_BITSET,				"FUTEX_WAKE_BITSET" },
 	{ FUTEX_WAIT|FUTEX_PRIVATE_FLAG,		"FUTEX_WAIT_PRIVATE" },
 	{ FUTEX_WAKE|FUTEX_PRIVATE_FLAG,		"FUTEX_WAKE_PRIVATE" },
 	{ FUTEX_FD|FUTEX_PRIVATE_FLAG,			"FUTEX_FD_PRIVATE" },
@@ -3110,7 +3235,8 @@ static const struct xlat futexops[] = {
 	{ FUTEX_LOCK_PI|FUTEX_PRIVATE_FLAG,		"FUTEX_LOCK_PI_PRIVATE" },
 	{ FUTEX_UNLOCK_PI|FUTEX_PRIVATE_FLAG,		"FUTEX_UNLOCK_PI_PRIVATE" },
 	{ FUTEX_TRYLOCK_PI|FUTEX_PRIVATE_FLAG,		"FUTEX_TRYLOCK_PI_PRIVATE" },
-	{ FUTEX_CMP_REQUEUE_PI|FUTEX_PRIVATE_FLAG,	"FUTEX_CMP_REQUEUE_PI_PRIVATE" },
+	{ FUTEX_WAIT_BITSET|FUTEX_PRIVATE_FLAG,		"FUTEX_WAIT_BITSET_PRIVATE" },
+	{ FUTEX_WAKE_BITSET|FUTEX_PRIVATE_FLAG,		"FUTEX_WAKE_BITSET_PRIVATE" },
 	{ 0,						NULL }
 };
 #ifndef FUTEX_OP_SET
@@ -3149,13 +3275,19 @@ sys_futex(tcp)
 struct tcb *tcp;
 {
     if (entering(tcp)) {
-	long int cmd = tcp->u_arg[1] & ~FUTEX_PRIVATE_FLAG;
+	long int cmd = tcp->u_arg[1] & 127;
 	tprintf("%p, ", (void *) tcp->u_arg[0]);
 	printxval(futexops, tcp->u_arg[1], "FUTEX_???");
 	tprintf(", %ld", tcp->u_arg[2]);
-	if (cmd == FUTEX_WAIT) {
+	if (cmd == FUTEX_WAKE_BITSET)
+		tprintf(", %lx", tcp->u_arg[5]);
+	else if (cmd == FUTEX_WAIT) {
 		tprintf(", ");
 		printtv(tcp, tcp->u_arg[3]);
+	} else if (cmd == FUTEX_WAIT_BITSET) {
+		tprintf(", ");
+		printtv(tcp, tcp->u_arg[3]);
+		tprintf(", %lx", tcp->u_arg[5]);
 	} else if (cmd == FUTEX_REQUEUE)
 		tprintf(", %ld, %p", tcp->u_arg[3], (void *) tcp->u_arg[4]);
 	else if (cmd == FUTEX_CMP_REQUEUE)
