@@ -30,7 +30,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: signal.c,v 1.61 2007/08/02 01:15:59 roland Exp $
+ *	$Id: signal.c,v 1.68 2008/08/20 01:59:40 roland Exp $
  */
 
 #include "defs.h"
@@ -97,12 +97,17 @@ typedef struct {
 	struct regs		si_regs;
 	int			si_mask;
 } m_siginfo_t;
+#elif defined (MIPS)
+typedef struct {
+	struct pt_regs		si_regs;
+	int			si_mask;
+} m_siginfo_t;
 #elif defined HAVE_ASM_SIGCONTEXT_H
 #if !defined(IA64) && !defined(X86_64)
 #include <asm/sigcontext.h>
 #endif /* !IA64 && !X86_64 */
 #else /* !HAVE_ASM_SIGCONTEXT_H */
-#ifdef I386
+#if defined I386 && !defined HAVE_STRUCT_SIGCONTEXT_STRUCT
 struct sigcontext_struct {
 	unsigned short gs, __gsh;
 	unsigned short fs, __fsh;
@@ -210,10 +215,16 @@ static const struct xlat sigact_flags[] = {
 #ifdef SA_INTERRUPT
 	{ SA_INTERRUPT,	"SA_INTERRUPT"	},
 #endif
-#ifdef SA_NOMASK
+#ifdef SA_NODEFER
+	{ SA_NODEFER,	"SA_NODEFER"	},
+#endif
+#if defined SA_NOMASK && SA_NODEFER != SA_NOMASK
 	{ SA_NOMASK,	"SA_NOMASK"	},
 #endif
-#ifdef SA_ONESHOT
+#ifdef SA_RESETHAND
+	{ SA_RESETHAND,	"SA_RESETHAND"	},
+#endif
+#if defined SA_ONESHOT && SA_ONESHOT != SA_RESETHAND
 	{ SA_ONESHOT,	"SA_ONESHOT"	},
 #endif
 #ifdef SA_SIGINFO
@@ -1109,23 +1120,20 @@ struct tcb *tcp;
 	else if (umove(tcp, addr, &sa) < 0)
 		tprintf("{...}");
 	else {
-		switch ((long) sa.SA_HANDLER) {
-		case (long) SIG_ERR:
-			tprintf("{SIG_ERR}");
-			break;
-		case (long) SIG_DFL:
-			tprintf("{SIG_DFL}");
-			break;
-		case (long) SIG_IGN:
+		if (sa.SA_HANDLER == SIG_ERR)
+			tprintf("{SIG_ERR, ");
+		else if (sa.SA_HANDLER == SIG_DFL)
+			tprintf("{SIG_DFL, ");
+		else if (sa.SA_HANDLER == SIG_DFL) {
 #ifndef USE_PROCFS
 			if (tcp->u_arg[0] == SIGTRAP) {
 				tcp->flags |= TCB_SIGTRAPPED;
 				kill(tcp->pid, SIGSTOP);
 			}
 #endif /* !USE_PROCFS */
-			tprintf("{SIG_IGN}");
-			break;
-		default:
+			tprintf("{SIG_IGN, ");
+		}
+		else {
 #ifndef USE_PROCFS
 			if (tcp->u_arg[0] == SIGTRAP) {
 				tcp->flags |= TCB_SIGTRAPPED;
@@ -1165,13 +1173,13 @@ struct tcb *tcp;
 		printsignal(tcp->u_arg[0]);
 		tprintf(", ");
 		switch (tcp->u_arg[1]) {
-		case (int) SIG_ERR:
+		case (long) SIG_ERR:
 			tprintf("SIG_ERR");
 			break;
-		case (int) SIG_DFL:
+		case (long) SIG_DFL:
 			tprintf("SIG_DFL");
 			break;
-		case (int) SIG_IGN:
+		case (long) SIG_IGN:
 #ifndef USE_PROCFS
 			if (tcp->u_arg[0] == SIGTRAP) {
 				tcp->flags |= TCB_SIGTRAPPED;
@@ -1193,11 +1201,11 @@ struct tcb *tcp;
 	}
 	else {
 		switch (tcp->u_rval) {
-		    case (int) SIG_ERR:
+		    case (long) SIG_ERR:
 			tcp->auxstr = "SIG_ERR"; break;
-		    case (int) SIG_DFL:
+		    case (long) SIG_DFL:
 			tcp->auxstr = "SIG_DFL"; break;
-		    case (int) SIG_IGN:
+		    case (long) SIG_IGN:
 			tcp->auxstr = "SIG_IGN"; break;
 		    default:
 			tcp->auxstr = NULL;
@@ -1424,27 +1432,55 @@ struct tcb *tcp;
 	}
 	return 0;
 #else
-#ifdef MIPS
+#if defined (LINUX_MIPSN32) || defined (LINUX_MIPSN64)
+	/* This decodes rt_sigreturn.  The 64-bit ABIs do not have
+	   sigreturn.  */
 	long sp;
-	struct sigcontext sc;
+	struct ucontext uc;
 
 	if(entering(tcp)) {
 	  	tcp->u_arg[0] = 0;
 		if (upeek(tcp->pid, REG_SP, &sp) < 0)
 		  	return 0;
-		if (umove(tcp, sp, &sc) < 0)
+		/* There are six words followed by a 128-byte siginfo.  */
+		sp = sp + 6 * 4 + 128;
+		if (umove(tcp, sp, &uc) < 0)
 		  	return 0;
 		tcp->u_arg[0] = 1;
-# ifdef HAVE_STRUCT_SIGCONTEXT_SC_HI2
-		tcp->u_arg[1] = sc.sc_hi2;
-# else
-		tcp->u_arg[1] = sc.sc_sigset;
-# endif
+		tcp->u_arg[1] = *(long *) &uc.uc_sigmask;
 	} else {
+		sigset_t sigm;
+		long_to_sigset(tcp->u_arg[1], &sigm);
 	  	tcp->u_rval = tcp->u_error = 0;
 		if(tcp->u_arg[0] == 0)
 		  	return 0;
-		tcp->auxstr = sprintsigmask("mask now ", tcp->u_arg[1], 0);
+		tcp->auxstr = sprintsigmask("mask now ", &sigm, 0);
+		return RVAL_NONE | RVAL_STR;
+	}
+	return 0;
+#else
+#ifdef MIPS
+	long sp;
+	struct pt_regs regs;
+	m_siginfo_t si;
+
+	if(ptrace(PTRACE_GETREGS, tcp->pid, (char *)&regs, 0) < 0) {
+		perror("sigreturn: PTRACE_GETREGS ");
+		return 0;
+	}
+	if(entering(tcp)) {
+	  	tcp->u_arg[0] = 0;
+		sp = regs.regs[29];
+		if (umove(tcp, sp, &si) < 0)
+		tcp->u_arg[0] = 1;
+		tcp->u_arg[1] = si.si_mask;
+	} else {
+		sigset_t sigm;
+		long_to_sigset(tcp->u_arg[1], &sigm);
+	  	tcp->u_rval = tcp->u_error = 0;
+		if(tcp->u_arg[0] == 0)
+			return 0;
+		tcp->auxstr = sprintsigmask("mask now ", &sigm, 0);
 		return RVAL_NONE | RVAL_STR;
 	}
 	return 0;
@@ -1453,6 +1489,7 @@ struct tcb *tcp;
 #warning         (no problem, just a reminder :-)
 	return 0;
 #endif /* MIPS */
+#endif /* LINUX_MIPSN32 || LINUX_MIPSN64 */
 #endif /* SPARC || SPARC64 */
 #endif /* ALPHA */
 #endif /* !M68K */
@@ -1701,7 +1738,13 @@ sys_kill(tcp)
 struct tcb *tcp;
 {
 	if (entering(tcp)) {
-		tprintf("%ld, %s", tcp->u_arg[0], signame(tcp->u_arg[1]));
+		/*
+		 * Sign-extend a 32-bit value when that's what it is.
+		 */
+		long pid = tcp->u_arg[0];
+		if (personality_wordsize[current_personality] < sizeof pid)
+			pid = (long) (int) pid;
+		tprintf("%ld, %s", pid, signame(tcp->u_arg[1]));
 	}
 	return 0;
 }
@@ -1819,7 +1862,7 @@ struct new_sigaction
 };
 
 
-	int
+int
 sys_rt_sigaction(tcp)
 	struct tcb *tcp;
 {
@@ -1840,38 +1883,33 @@ sys_rt_sigaction(tcp)
 	else if (umove(tcp, addr, &sa) < 0)
 		tprintf("{...}");
 	else {
-		switch ((long) sa.__sigaction_handler.__sa_handler) {
-			case (long) SIG_ERR:
-				tprintf("{SIG_ERR}");
-				break;
-			case (long) SIG_DFL:
-				tprintf("{SIG_DFL}");
-				break;
-			case (long) SIG_IGN:
-				tprintf("{SIG_IGN}");
-				break;
-			default:
-				tprintf("{%#lx, ",
-						(long) sa.__sigaction_handler.__sa_handler);
-				sigemptyset(&sigset);
+		if (sa.__sigaction_handler.__sa_handler == SIG_ERR)
+			tprintf("{SIG_ERR, ");
+		else if (sa.__sigaction_handler.__sa_handler == SIG_DFL)
+			tprintf("{SIG_DFL, ");
+		else if (sa.__sigaction_handler.__sa_handler == SIG_DFL)
+			tprintf("{SIG_IGN, ");
+		else
+			tprintf("{%#lx, ",
+				(long) sa.__sigaction_handler.__sa_handler);
+		sigemptyset(&sigset);
 #ifdef LINUXSPARC
-				if (tcp->u_arg[4] <= sizeof(sigset))
-					memcpy(&sigset, &sa.sa_mask, tcp->u_arg[4]);
+		if (tcp->u_arg[4] <= sizeof(sigset))
+			memcpy(&sigset, &sa.sa_mask, tcp->u_arg[4]);
 #else
-				if (tcp->u_arg[3] <= sizeof(sigset))
-					memcpy(&sigset, &sa.sa_mask, tcp->u_arg[3]);
+		if (tcp->u_arg[3] <= sizeof(sigset))
+			memcpy(&sigset, &sa.sa_mask, tcp->u_arg[3]);
 #endif
-				else
-					memcpy(&sigset, &sa.sa_mask, sizeof(sigset));
-				printsigmask(&sigset, 1);
-				tprintf(", ");
-				printflags(sigact_flags, sa.sa_flags, "SA_???");
+		else
+			memcpy(&sigset, &sa.sa_mask, sizeof(sigset));
+		printsigmask(&sigset, 1);
+		tprintf(", ");
+		printflags(sigact_flags, sa.sa_flags, "SA_???");
 #ifdef SA_RESTORER
-				if (sa.sa_flags & SA_RESTORER)
-					tprintf(", %p", sa.sa_restorer);
+		if (sa.sa_flags & SA_RESTORER)
+			tprintf(", %p", sa.sa_restorer);
 #endif
-				tprintf("}");
-		}
+		tprintf("}");
 	}
 	if (entering(tcp))
 		tprintf(", ");
