@@ -30,7 +30,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscall.c,v 1.88 2006/12/21 21:15:04 ldv Exp $
+ *	$Id: syscall.c,v 1.96 2008/08/25 03:16:26 roland Exp $
  */
 
 #include "defs.h"
@@ -324,18 +324,19 @@ qual_syscall(s, opt, not)
 
   	if (isdigit((unsigned char)*s)) {
  		int i = atoi(s);
- 		if (i < 0 || i >= nsyscalls)
+		if (i < 0 || i >= MAX_QUALS)
  			return -1;
  		qualify_one(i, opt, not, -1);
  		return 0;
 	}
-	for (i = 0; i < nsyscalls; i++) {
+	for (i = 0; i < nsyscalls0; i++)
 		if (strcmp(s, sysent0[i].sys_name) == 0) {
 			qualify_one(i, opt, not, 0);
 			rc = 0;
 		}
 
 #if SUPPORTED_PERSONALITIES >= 2
+	for (i = 0; i < nsyscalls1; i++)
 		if (strcmp(s, sysent1[i].sys_name) == 0) {
 			qualify_one(i, opt, not, 1);
 			rc = 0;
@@ -343,12 +344,13 @@ qual_syscall(s, opt, not)
 #endif /* SUPPORTED_PERSONALITIES >= 2 */
 
 #if SUPPORTED_PERSONALITIES >= 3
+	for (i = 0; i < nsyscalls2; i++)
 		if (strcmp(s, sysent2[i].sys_name) == 0) {
 			qualify_one(i, opt, not, 2);
 			rc = 0;
 		}
 #endif /* SUPPORTED_PERSONALITIES >= 3 */
-	}
+
 	return rc;
 }
 
@@ -466,20 +468,22 @@ char *s;
 	}
 	for (p = strtok(s, ","); p; p = strtok(NULL, ",")) {
 		if (opt->bitflag == QUAL_TRACE && (n = lookup_class(p)) > 0) {
-			for (i = 0; i < MAX_QUALS; i++) {
+			for (i = 0; i < nsyscalls0; i++)
 				if (sysent0[i].sys_flags & n)
 					qualify_one(i, opt, not, 0);
 
 #if SUPPORTED_PERSONALITIES >= 2
+			for (i = 0; i < nsyscalls1; i++)
 				if (sysent1[i].sys_flags & n)
 					qualify_one(i, opt, not, 1);
 #endif /* SUPPORTED_PERSONALITIES >= 2 */
 
 #if SUPPORTED_PERSONALITIES >= 3
+			for (i = 0; i < nsyscalls2; i++)
 				if (sysent2[i].sys_flags & n)
 					qualify_one(i, opt, not, 2);
 #endif /* SUPPORTED_PERSONALITIES >= 3 */
-			}
+
 			continue;
 		}
 		if (opt->qualify(p, opt, not)) {
@@ -580,50 +584,6 @@ static const struct subcall subcalls_table[] = {
 
 #if !(defined(LINUX) && ( defined(ALPHA) || defined(MIPS) ))
 
-static const int socket_map [] = {
-	       /* SYS_SOCKET      */ 97,
-	       /* SYS_BIND        */ 104,
-	       /* SYS_CONNECT     */ 98,
-	       /* SYS_LISTEN      */ 106,
-	       /* SYS_ACCEPT      */ 99,
-	       /* SYS_GETSOCKNAME */ 150,
-	       /* SYS_GETPEERNAME */ 141,
-	       /* SYS_SOCKETPAIR  */ 135,
-	       /* SYS_SEND        */ 101,
-	       /* SYS_RECV        */ 102,
-	       /* SYS_SENDTO      */ 133,
-	       /* SYS_RECVFROM    */ 125,
-	       /* SYS_SHUTDOWN    */ 134,
-	       /* SYS_SETSOCKOPT  */ 105,
-	       /* SYS_GETSOCKOPT  */ 118,
-	       /* SYS_SENDMSG     */ 114,
-	       /* SYS_RECVMSG     */ 113
-};
-
-#if defined (SPARC) || defined (SPARC64)
-static void
-sparc_socket_decode (tcp)
-struct tcb *tcp;
-{
-	volatile long addr;
-	volatile int i, n;
-
-	if (tcp->u_arg [0] < 1 || tcp->u_arg [0] > sizeof(socket_map)/sizeof(int)+1){
-		return;
-	}
-	tcp->scno = socket_map [tcp->u_arg [0]-1];
-	n = tcp->u_nargs = sysent [tcp->scno].nargs;
-	addr = tcp->u_arg [1];
-	for (i = 0; i < n; i++){
-	        int arg;
-		if (umoven (tcp, addr, sizeof (arg), (void *) &arg) < 0)
-			arg = 0;
-		tcp->u_arg [i] = arg;
-		addr += sizeof (arg);
-	}
-}
-#endif
-
 static void
 decode_subcall(tcp, subcall, nsubcalls, style)
 struct tcb *tcp;
@@ -794,6 +754,9 @@ internal_syscall(struct tcb *tcp)
 #elif defined (SPARC) || defined (SPARC64)
 	static struct regs regs;
 	static unsigned long trap;
+#elif defined(LINUX_MIPSN32)
+	static long long a3;
+	static long long r2;
 #elif defined(MIPS)
 	static long a3;
 	static long r2;
@@ -1042,6 +1005,14 @@ struct tcb *tcp;
 	 * We only need to grab the syscall number on syscall entry.
 	 */
 	if (regs.ARM_ip == 0) {
+		if (!(tcp->flags & TCB_INSYSCALL)) {
+			/* Check if we return from execve. */
+			if (tcp->flags & TCB_WAITEXECVE) {
+				tcp->flags &= ~TCB_WAITEXECVE;
+				return 0;
+			}
+		}
+
 		/*
 		 * Note: we only deal with only 32-bit CPUs here.
 		 */
@@ -1084,6 +1055,14 @@ struct tcb *tcp;
 				scno &= 0x000fffff;
 			}
 		}
+		if (scno & 0x0f0000) {
+			/*
+			 * Handle ARM specific syscall
+			 */
+			set_personality(1);
+			scno &= 0x0000ffff;
+		} else
+			set_personality(0);
 
 		if (tcp->flags & TCB_INSYSCALL) {
 			fprintf(stderr, "pid %d stray syscall entry\n", tcp->pid);
@@ -1098,14 +1077,44 @@ struct tcb *tcp;
 #elif defined (M68K)
 	if (upeek(pid, 4*PT_ORIG_D0, &scno) < 0)
 		return -1;
+#elif defined (LINUX_MIPSN32)
+	unsigned long long regs[38];
+
+	if (ptrace (PTRACE_GETREGS, pid, NULL, (long) &regs) < 0)
+		return -1;
+	a3 = regs[REG_A3];
+	r2 = regs[REG_V0];
+
+	if(!(tcp->flags & TCB_INSYSCALL)) {
+		scno = r2;
+
+		/* Check if we return from execve. */
+		if (scno == 0 && tcp->flags & TCB_WAITEXECVE) {
+			tcp->flags &= ~TCB_WAITEXECVE;
+			return 0;
+		}
+
+		if (scno < 0 || scno > nsyscalls) {
+			if(a3 == 0 || a3 == -1) {
+				if(debug)
+					fprintf (stderr, "stray syscall exit: v0 = %ld\n", scno);
+				return 0;
+			}
+		}
+	}
 #elif defined (MIPS)
 	if (upeek(pid, REG_A3, &a3) < 0)
 	  	return -1;
-
 	if(!(tcp->flags & TCB_INSYSCALL)) {
 	  	if (upeek(pid, REG_V0, &scno) < 0)
 		  	return -1;
 
+		/* Check if we return from execve. */
+		if (scno == 0 && tcp->flags & TCB_WAITEXECVE) {
+			tcp->flags &= ~TCB_WAITEXECVE;
+			return 0;
+		}
+
 		if (scno < 0 || scno > nsyscalls) {
 			if(a3 == 0 || a3 == -1) {
 				if(debug)
@@ -1464,6 +1473,23 @@ struct tcb *tcp;
 	return 1;
 }
 
+#ifdef LINUX
+/*
+ * Check the syscall return value register value for whether it is
+ * a negated errno code indicating an error, or a success return value.
+ */
+static inline int
+is_negated_errno(unsigned long int val)
+{
+	unsigned long int max = -(long int) nerrnos;
+	if (personality_wordsize[current_personality] < sizeof(val)) {
+		val = (unsigned int) val;
+		max = (unsigned int) max;
+	}
+	return val > max;
+}
+#endif
+
 static int
 get_error(tcp)
 struct tcb *tcp;
@@ -1471,57 +1497,57 @@ struct tcb *tcp;
 	int u_error = 0;
 #ifdef LINUX
 #if defined(S390) || defined(S390X)
-		if (gpr2 && (unsigned) -gpr2 < nerrnos) {
-			tcp->u_rval = -1;
-			u_error = -gpr2;
-		}
-		else {
-			tcp->u_rval = gpr2;
-			u_error = 0;
-		}
+	if (is_negated_errno(gpr2)) {
+		tcp->u_rval = -1;
+		u_error = -gpr2;
+	}
+	else {
+		tcp->u_rval = gpr2;
+		u_error = 0;
+	}
 #else /* !S390 && !S390X */
 #ifdef I386
-		if (eax < 0 && -eax < nerrnos) {
-			tcp->u_rval = -1;
-			u_error = -eax;
-		}
-		else {
-			tcp->u_rval = eax;
-			u_error = 0;
-		}
+	if (is_negated_errno(eax)) {
+		tcp->u_rval = -1;
+		u_error = -eax;
+	}
+	else {
+		tcp->u_rval = eax;
+		u_error = 0;
+	}
 #else /* !I386 */
 #ifdef X86_64
-		if (rax < 0 && -rax < nerrnos) {
-			tcp->u_rval = -1;
-			u_error = -rax;
-		}
-		else {
-			tcp->u_rval = rax;
-			u_error = 0;
-		}
+	if (is_negated_errno(rax)) {
+		tcp->u_rval = -1;
+		u_error = -rax;
+	}
+	else {
+		tcp->u_rval = rax;
+		u_error = 0;
+	}
 #else
 #ifdef IA64
-		if (ia32) {
-			int err;
+	if (ia32) {
+		int err;
 
-			err = (int)r8;
-			if (err < 0 && -err < nerrnos) {
-				tcp->u_rval = -1;
-				u_error = -err;
-			}
-			else {
-				tcp->u_rval = err;
-				u_error = 0;
-			}
-		} else {
-			if (r10) {
-				tcp->u_rval = -1;
-				u_error = r8;
-			} else {
-				tcp->u_rval = r8;
-				u_error = 0;
-			}
+		err = (int)r8;
+		if (is_negated_errno(err)) {
+			tcp->u_rval = -1;
+			u_error = -err;
 		}
+		else {
+			tcp->u_rval = err;
+			u_error = 0;
+		}
+	} else {
+		if (r10) {
+			tcp->u_rval = -1;
+			u_error = r8;
+		} else {
+			tcp->u_rval = r8;
+			u_error = 0;
+		}
+	}
 #else /* !IA64 */
 #ifdef MIPS
 		if (a3) {
@@ -1533,7 +1559,7 @@ struct tcb *tcp;
 		}
 #else
 #ifdef POWERPC
-		if (result && (unsigned long) -result < nerrnos) {
+		if (is_negated_errno(result)) {
 			tcp->u_rval = -1;
 			u_error = -result;
 		}
@@ -1543,7 +1569,7 @@ struct tcb *tcp;
 		}
 #else /* !POWERPC */
 #ifdef M68K
-		if (d0 && (unsigned) -d0 < nerrnos) {
+		if (is_negated_errno(d0)) {
 			tcp->u_rval = -1;
 			u_error = -d0;
 		}
@@ -1553,7 +1579,7 @@ struct tcb *tcp;
 		}
 #else /* !M68K */
 #ifdef ARM
-		if (regs.ARM_r0 && (unsigned) -regs.ARM_r0 < nerrnos) {
+		if (is_negated_errno(regs.ARM_r0)) {
 			tcp->u_rval = -1;
 			u_error = -regs.ARM_r0;
 		}
@@ -1593,7 +1619,7 @@ struct tcb *tcp;
 		}
 #else /* !SPARC64 */
 #ifdef HPPA
-		if (r28 && (unsigned) -r28 < nerrnos) {
+		if (is_negated_errno(r28)) {
 			tcp->u_rval = -1;
 			u_error = -r28;
 		}
@@ -1603,19 +1629,19 @@ struct tcb *tcp;
 		}
 #else
 #ifdef SH
-               /* interpret R0 as return value or error number */
-               if (r0 && (unsigned) -r0 < nerrnos) {
-                       tcp->u_rval = -1;
-                       u_error = -r0;
-               }
-               else {
-                       tcp->u_rval = r0;
-                       u_error = 0;
-               }
+		/* interpret R0 as return value or error number */
+		if (is_negated_errno(r0)) {
+			tcp->u_rval = -1;
+			u_error = -r0;
+		}
+		else {
+			tcp->u_rval = r0;
+			u_error = 0;
+		}
 #else
 #ifdef SH64
                 /* interpret result as return value or error number */
-                if (r9 && (unsigned) -r9 < nerrnos) {
+                if (is_negated_errno(r9)) {
 	                tcp->u_rval = -1;
 	                u_error = -r9;
                 }
@@ -1764,6 +1790,7 @@ force_result(tcp, error, rval)
 		r2 = rval;
 		a3 = 0;
 	}
+	/* PTRACE_POKEUSER is OK even for n32 since rval is only a long.  */
 	if (ptrace(PTRACE_POKEUSER, tcp->pid, (char*)(REG_A3), a3) < 0 ||
 	    ptrace(PTRACE_POKEUSER, tcp->pid, (char*)(REG_V0), r2) < 0)
 	    	return -1;
@@ -1936,20 +1963,21 @@ struct tcb *tcp;
 #elif defined (IA64)
 	{
 		if (!ia32) {
-			unsigned long *out0, *rbs_end, cfm, sof, sol, i;
+			unsigned long *out0, cfm, sof, sol, i;
+			long rbs_end;
 			/* be backwards compatible with kernel < 2.4.4... */
 #			ifndef PT_RBS_END
 #			  define PT_RBS_END	PT_AR_BSP
 #			endif
 
-			if (upeek(pid, PT_RBS_END, (long *) &rbs_end) < 0)
+			if (upeek(pid, PT_RBS_END, &rbs_end) < 0)
 				return -1;
 			if (upeek(pid, PT_CFM, (long *) &cfm) < 0)
 				return -1;
 
 			sof = (cfm >> 0) & 0x7f;
 			sol = (cfm >> 7) & 0x7f;
-			out0 = ia64_rse_skip_regs(rbs_end, -sof + sol);
+			out0 = ia64_rse_skip_regs((unsigned long *) rbs_end, -sof + sol);
 
 			if (tcp->scno >= 0 && tcp->scno < nsyscalls
 			    && sysent[tcp->scno].nargs != -1)
@@ -1989,6 +2017,27 @@ struct tcb *tcp;
 				tcp->u_nargs = 5;
 		}
 	}
+#elif defined (LINUX_MIPSN32) || defined (LINUX_MIPSN64)
+	/* N32 and N64 both use up to six registers.  */
+	{
+		unsigned long long regs[38];
+	  	int i, nargs;
+
+		if (tcp->scno >= 0 && tcp->scno < nsyscalls && sysent[tcp->scno].nargs != -1)
+			nargs = tcp->u_nargs = sysent[tcp->scno].nargs;
+		else
+     	        	nargs = tcp->u_nargs = MAX_ARGS;
+
+		if (ptrace (PTRACE_GETREGS, pid, NULL, (long) &regs) < 0)
+			return -1;
+
+		for(i = 0; i < nargs; i++) {
+			tcp->u_arg[i] = regs[REG_A0 + i];
+# if defined (LINUX_MIPSN32)
+			tcp->ext_arg[i] = regs[REG_A0 + i];
+# endif
+		}
+	}
 #elif defined (MIPS)
 	{
 	  	long sp;
@@ -2381,23 +2430,18 @@ trace_syscall(struct tcb *tcp)
 		return res;
 
 	switch (known_scno(tcp)) {
-#ifdef LINUX
-#if !defined (ALPHA) && !defined(SPARC) && !defined(SPARC64) && !defined(MIPS) && !defined(HPPA)
+#ifdef SYS_socket_subcall
 	case SYS_socketcall:
 		decode_subcall(tcp, SYS_socket_subcall,
 			SYS_socket_nsubcalls, deref_style);
 		break;
+#endif
+#ifdef SYS_ipc_subcall
 	case SYS_ipc:
 		decode_subcall(tcp, SYS_ipc_subcall,
 			SYS_ipc_nsubcalls, shift_style);
 		break;
-#endif /* !ALPHA && !MIPS && !SPARC && !SPARC64 && !HPPA */
-#if defined (SPARC) || defined (SPARC64)
-	case SYS_socketcall:
-		sparc_socket_decode (tcp);
-		break;
 #endif
-#endif /* LINUX */
 #ifdef SVR4
 #ifdef SYS_pgrpsys_subcall
 	case SYS_pgrpsys:
