@@ -24,7 +24,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: term.c,v 1.8 2005/06/01 19:02:38 roland Exp $
+ *	$Id: term.c,v 1.9 2008/07/22 00:21:43 roland Exp $
  */
 
 #include "defs.h"
@@ -337,10 +337,10 @@ long code, arg;
 	case TIOCMBIS:
 	case TIOCMBIC:
 	case TIOCMSET:
-		if (umove(tcp, arg, &arg) < 0)
+		if (umove(tcp, arg, &i) < 0)
 			return 0;
 		tprintf(", [");
-		printflags(modem_flags, arg, "TIOCM_???");
+		printflags(modem_flags, i, "TIOCM_???");
 		tprintf("]");
 		return 1;
 #endif /* TIOCMGET */
@@ -414,7 +414,7 @@ long code, arg;
 	case TIOCGPTN:
 #endif
 		tprintf(", ");
-		printnum(tcp, arg, "%d");
+		printnum_int(tcp, arg, "%d");
 		return 1;
 
 #if 0
