@@ -26,7 +26,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: time.c,v 1.22 2007/08/02 01:25:34 roland Exp $
+ *	$Id: time.c,v 1.24 2008/05/20 04:56:13 roland Exp $
  */
 
 #include "defs.h"
@@ -150,6 +150,76 @@ sprinttv(struct tcb *tcp, long addr, enum bitness_t bitness, char *buf)
 	}
 }
 
+void print_timespec (struct tcb *tcp, long addr)
+{
+	if (addr == 0)
+		tprintf("NULL");
+	else if (!verbose(tcp))
+		tprintf("%#lx", addr);
+	else {
+		int     rc;
+
+#if defined(LINUX) && SUPPORTED_PERSONALITIES > 1
+		if (personality_wordsize[current_personality] == 4)
+		{
+			struct timeval32 tv;
+
+			if ((rc = umove(tcp, addr, &tv)) >= 0)
+				tprintf("{%u, %u}",
+					tv.tv_sec, tv.tv_usec);
+		} else
+		{
+#endif
+			struct timespec ts;
+
+			if ((rc = umove(tcp, addr, &ts)) >= 0)
+				tprintf("{%lu, %lu}",
+					(unsigned long) ts.tv_sec,
+					(unsigned long) ts.tv_nsec);
+#if defined(LINUX) && SUPPORTED_PERSONALITIES > 1
+		}
+#endif
+
+		if (rc < 0)
+			tprintf("{...}");
+	}
+}
+
+void sprint_timespec (char *buf, struct tcb *tcp, long addr)
+{
+	if (addr == 0)
+		strcpy(buf, "NULL");
+	else if (!verbose(tcp))
+		sprintf(buf, "%#lx", addr);
+	else {
+		int     rc;
+
+#if defined(LINUX) && SUPPORTED_PERSONALITIES > 1
+		if (personality_wordsize[current_personality] == 4)
+		{
+			struct timeval32 tv;
+
+			if ((rc = umove(tcp, addr, &tv)) >= 0)
+				sprintf(buf, "{%u, %u}",
+					tv.tv_sec, tv.tv_usec);
+		} else
+		{
+#endif
+			struct timespec ts;
+
+			if ((rc = umove(tcp, addr, &ts)) >= 0)
+				sprintf(buf, "{%lu, %lu}",
+					(unsigned long) ts.tv_sec,
+					(unsigned long) ts.tv_nsec);
+#if defined(LINUX) && SUPPORTED_PERSONALITIES > 1
+		}
+#endif
+
+		if (rc < 0)
+			strcpy(buf, "{...}");
+	}
+}
+
 int
 sys_time(tcp)
 struct tcb *tcp;
@@ -919,4 +989,41 @@ struct tcb *tcp;
 	}
 	return 0;
 }
+
+int
+sys_timerfd_create(struct tcb *tcp)
+{
+	if (entering(tcp)) {
+		printxval(clocknames, tcp->u_arg[0], "CLOCK_???");
+		tprintf(", ");
+		printflags(timerfdflags, tcp->u_arg[1], "TFD_???");
+	}
+	return 0;
+}
+
+int
+sys_timerfd_settime(struct tcb *tcp)
+{
+	if (entering(tcp)) {
+		tprintf("%ld, ", tcp->u_arg[0]);
+		printflags(timerfdflags, tcp->u_arg[1], "TFD_???");
+		tprintf(", ");
+		printitv(tcp, tcp->u_arg[2]);
+		tprintf(", ");
+		printitv(tcp, tcp->u_arg[3]);
+	}
+	return 0;
+}
+
+int
+sys_timerfd_gettime(struct tcb *tcp)
+{
+	if (entering(tcp)) {
+		tprintf("%ld, ", tcp->u_arg[0]);
+		tprintf(", ");
+		printitv(tcp, tcp->u_arg[1]);
+	}
+	return 0;
+}
+
 #endif /* LINUX */
