@@ -30,7 +30,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: util.c,v 1.71 2007/08/02 02:22:06 roland Exp $
+ *	$Id: util.c,v 1.79 2008/08/06 21:43:35 kratochvil Exp $
  */
 
 #include "defs.h"
@@ -280,6 +280,37 @@ int flags;
 	return n;
 }
 
+/*
+ * Interpret `xlat' as an array of flags/
+ * Print to static string the entries whose bits are on in `flags'
+ * Return static string.
+ */
+const char *
+sprintflags(const char *prefix, const struct xlat *xlat, int flags)
+{
+	static char outstr[1024];
+	int found = 0;
+
+	strcpy(outstr, prefix);
+
+	for (; xlat->str; xlat++) {
+		if ((flags & xlat->val) == xlat->val) {
+			if (found)
+				strcat(outstr, "|");
+			strcat(outstr, xlat->str);
+			flags &= ~xlat->val;
+			found = 1;
+		}
+	}
+	if (flags) {
+		if (found)
+			strcat(outstr, "|");
+		sprintf(outstr + strlen(outstr), "%#x", flags);
+	}
+
+	return outstr;
+}
+
 int
 printflags(xlat, flags, dflt)
 const struct xlat *xlat;
@@ -376,73 +407,132 @@ unsigned long uid;
 
 static char path[MAXPATHLEN + 1];
 
-static void
-string_quote(str)
-const char *str;
+static int
+string_quote(const char *instr, char *outstr, int len, int size)
 {
-	char buf[2 * MAXPATHLEN + 1];
-	char *s;
+	const unsigned char *ustr = (const unsigned char *) instr;
+	char *s = outstr;
+	int usehex = 0, c, i;
 
-	if (!strpbrk(str, "\"\'\\")) {
-		tprintf("\"%s\"", str);
-		return;
-	}
-	for (s = buf; *str; str++) {
-		switch (*str) {
-		case '\"': case '\'': case '\\':
-			*s++ = '\\'; *s++ = *str; break;
-		default:
-			*s++ = *str; break;
+	if (xflag > 1)
+		usehex = 1;
+	else if (xflag) {
+		for (i = 0; i < size; ++i) {
+			c = ustr[i];
+			if (len < 0 && i == size - 2 && c != '\0')
+				++i;
+			if (len < 0 && c == '\0')
+				break;
+			if (!isprint(c) && !isspace(c)) {
+				usehex = 1;
+				break;
+			}
 		}
 	}
+
+	*s++ = '\"';
+
+	if (usehex) {
+		for (i = 0; i < size; ++i) {
+			c = ustr[i];
+			if (len < 0 && c == '\0')
+				break;
+			sprintf(s, "\\x%02x", c);
+			s += 4;
+		}
+	} else {
+		for (i = 0; i < size; ++i) {
+			c = ustr[i];
+			if (len < 0 && i == size - 2 && c != '\0')
+				++i;
+			if (len < 0 && c == '\0')
+				break;
+			switch (c) {
+				case '\"': case '\\':
+					*s++ = '\\';
+					*s++ = c;
+					break;
+				case '\f':
+					*s++ = '\\';
+					*s++ = 'f';
+					break;
+				case '\n':
+					*s++ = '\\';
+					*s++ = 'n';
+					break;
+				case '\r':
+					*s++ = '\\';
+					*s++ = 'r';
+					break;
+				case '\t':
+					*s++ = '\\';
+					*s++ = 't';
+					break;
+				case '\v':
+					*s++ = '\\';
+					*s++ = 'v';
+					break;
+				default:
+					if (isprint(c))
+						*s++ = c;
+					else if (i + 1 < size
+						 && isdigit(ustr[i + 1])) {
+						sprintf(s, "\\%03o", c);
+						s += 4;
+					} else {
+						sprintf(s, "\\%o", c);
+						s += strlen(s);
+					}
+					break;
+			}
+		}
+	}
+
+	*s++ = '\"';
 	*s = '\0';
-	tprintf("\"%s\"", buf);
+
+	/* Return nonzero if the string was unterminated.  */
+	return i == size;
 }
 
 void
-printpath(tcp, addr)
-struct tcb *tcp;
-long addr;
+printpathn(struct tcb *tcp, long addr, int n)
 {
-	if (addr == 0)
-		tprintf("NULL");
-	else if (umovestr(tcp, addr, MAXPATHLEN, path) < 0)
-		tprintf("%#lx", addr);
-	else
-		string_quote(path);
-	return;
-}
-
-void
-printpathn(tcp, addr, n)
-struct tcb *tcp;
-long addr;
-int n;
-{
-	if (n >= sizeof path)
+	if (n > sizeof path - 1)
 		n = sizeof path - 1;
 
-	if (addr == 0)
+	if (addr == 0) {
 		tprintf("NULL");
-	else 	if (umovestr(tcp, addr, n, path) < 0)
+		return;
+	}
+
+	path[n] = '\0';
+	if (umovestr(tcp, addr, n + 1, path) < 0)
 		tprintf("%#lx", addr);
 	else {
-		path[n] = '\0';
-		string_quote(path);
+		static char outstr[4*(sizeof path - 1) + sizeof "\"...\""];
+		int trunc = (path[n] != '\0');
+
+		if (trunc)
+			path[n] = '\0';
+		if (string_quote(path, outstr, -1, n + 1) || trunc)
+			strcat(outstr, "...");
+		tprintf("%s", outstr);
 	}
 }
 
 void
-printstr(tcp, addr, len)
-struct tcb *tcp;
-long addr;
-int len;
+printpath(struct tcb *tcp, long addr)
 {
-	static unsigned char *str = NULL;
+	printpathn(tcp, addr, sizeof path - 1);
+}
+
+void
+printstr(struct tcb *tcp, long addr, int len)
+{
+	static char *str = NULL;
 	static char *outstr;
-	int i, n, c, usehex;
-	char *s, *outend;
-	int trunc;
+	int size;
 
 	if (!addr) {
 		tprintf("NULL");
@@ -457,94 +547,25 @@ int len;
 			return;
 		}
 	}
-	outend = outstr + max_strlen * 4;
+
 	if (len < 0) {
-		n = max_strlen + 1;
-		if (umovestr(tcp, addr, n, (char *) str) < 0) {
+		size = max_strlen + 1;
+		if (umovestr(tcp, addr, size, str) < 0) {
 			tprintf("%#lx", addr);
 			return;
 		}
 	}
 	else {
-		n = MIN(len, max_strlen + 1);
-		if (umoven(tcp, addr, n, (char *) str) < 0) {
+		size = MIN(len, max_strlen + 1);
+		if (umoven(tcp, addr, size, str) < 0) {
 			tprintf("%#lx", addr);
 			return;
 		}
 	}
 
-	trunc = n > max_strlen && str[--n] != 0;
+	if (string_quote(str, outstr, len, size))
+		strcat(outstr, "...");
 
-	usehex = 0;
-	if (xflag > 1)
-		usehex = 1;
-	else if (xflag) {
-		for (i = 0; i < n; i++) {
-			c = str[i];
-			if (len < 0 && c == '\0')
-				break;
-			if (!isprint(c) && !isspace(c)) {
-				usehex = 1;
-				break;
-			}
-		}
-	}
-
-	s = outstr;
-	*s++ = '\"';
-
-	if (usehex) {
-		for (i = 0; i < n; i++) {
-			c = str[i];
-			if (len < 0 && c == '\0')
-				break;
-			sprintf(s, "\\x%02x", c);
-			s += 4;
-			if (s > outend)
-				break;
-		}
-	}
-	else {
-		for (i = 0; i < n; i++) {
-			c = str[i];
-			if (len < 0 && c == '\0')
-				break;
-			switch (c) {
-			case '\"': case '\'': case '\\':
-				*s++ = '\\'; *s++ = c; break;
-			case '\f':
-				*s++ = '\\'; *s++ = 'f'; break;
-			case '\n':
-				*s++ = '\\'; *s++ = 'n'; break;
-			case '\r':
-				*s++ = '\\'; *s++ = 'r'; break;
-			case '\t':
-				*s++ = '\\'; *s++ = 't'; break;
-			case '\v':
-				*s++ = '\\'; *s++ = 'v'; break;
-			default:
-				if (isprint(c))
-					*s++ = c;
-				else if (i < n - 1 && isdigit(str[i + 1])) {
-					sprintf(s, "\\%03o", c);
-					s += 4;
-				}
-				else {
-					sprintf(s, "\\%o", c);
-					s += strlen(s);
-				}
-				break;
-			}
-			if (s > outend)
-				break;
-		}
-	}
-
-	*s++ = '\"';
-	if (i < len || (len < 0 && (trunc || s > outend))) {
-		*s++ = '.'; *s++ = '.'; *s++ = '.';
-	}
-	*s = '\0';
 	tprintf("%s", outstr);
 }
 
@@ -1254,10 +1275,18 @@ struct tcb *tcp;
 
 #if defined LINUX
 
+#include "syscall.h"
+
 #include <sys/syscall.h>
 #ifndef CLONE_PTRACE
 # define CLONE_PTRACE    0x00002000
 #endif
+#ifndef CLONE_VFORK
+# define CLONE_VFORK     0x00004000
+#endif
+#ifndef CLONE_VM
+# define CLONE_VM        0x00000100
+#endif
 #ifndef CLONE_STOPPED
 # define CLONE_STOPPED   0x02000000
 #endif
@@ -1274,21 +1303,25 @@ typedef unsigned long *arg_setup_state;
 static int
 arg_setup(struct tcb *tcp, arg_setup_state *state)
 {
-	unsigned long *bsp, cfm, sof, sol;
+	unsigned long cfm, sof, sol;
+	long bsp;
 
-	if (ia32)
+	if (ia32) {
+		/* Satisfy a false GCC warning.  */
+		*state = NULL;
 		return 0;
+	}
 
-	if (upeek(tcp->pid, PT_AR_BSP, (long *) &bsp) < 0)
+	if (upeek(tcp->pid, PT_AR_BSP, &bsp) < 0)
 		return -1;
 	if (upeek(tcp->pid, PT_CFM, (long *) &cfm) < 0)
 		return -1;
 
 	sof = (cfm >> 0) & 0x7f;
 	sol = (cfm >> 7) & 0x7f;
-	bsp = ia64_rse_skip_regs(bsp, -sof + sol);
+	bsp = (long) ia64_rse_skip_regs((unsigned long *) bsp, -sof + sol);
 
-	*state = bsp;
+	*state = (unsigned long *) bsp;
 	return 0;
 }
 
@@ -1356,6 +1389,12 @@ set_arg1 (struct tcb *tcp, arg_setup_state *state, long val)
 	return errno ? -1 : 0;
 }
 
+/* ia64 does not return the input arguments from functions (and syscalls)
+   according to ia64 RSE (Register Stack Engine) behavior.  */
+
+# define restore_arg0(tcp, state, val) ((void) (state), 0)
+# define restore_arg1(tcp, state, val) ((void) (state), 0)
+
 #elif defined (SPARC) || defined (SPARC64)
 
 typedef struct regs arg_setup_state;
@@ -1452,6 +1491,7 @@ int
 setbpt(tcp)
 struct tcb *tcp;
 {
+	static int clone_scno[SUPPORTED_PERSONALITIES] = { SYS_clone };
 	extern int change_syscall(struct tcb *, int);
 	arg_setup_state state;
 
@@ -1460,6 +1500,20 @@ struct tcb *tcp;
 		return -1;
 	}
 
+	/*
+	 * It's a silly kludge to initialize this with a search at runtime.
+	 * But it's better than maintaining another magic thing in the
+	 * godforsaken tables.
+	 */
+	if (clone_scno[current_personality] == 0) {
+		int i;
+		for (i = 0; i < nsyscalls; ++i)
+			if (sysent[i].sys_func == sys_clone) {
+				clone_scno[current_personality] = i;
+				break;
+			}
+	}
+
 	switch (known_scno(tcp)) {
 #ifdef SYS_vfork
 	case SYS_vfork:
@@ -1471,7 +1525,7 @@ struct tcb *tcp;
 		if (arg_setup (tcp, &state) < 0
 		    || get_arg0 (tcp, &state, &tcp->inst[0]) < 0
 		    || get_arg1 (tcp, &state, &tcp->inst[1]) < 0
-		    || change_syscall(tcp, SYS_clone) < 0
+		    || change_syscall(tcp, clone_scno[current_personality]) < 0
 		    || set_arg0 (tcp, &state, CLONE_PTRACE|SIGCHLD) < 0
 		    || set_arg1 (tcp, &state, 0) < 0
 		    || arg_finish_change (tcp, &state) < 0)
@@ -1486,12 +1540,21 @@ struct tcb *tcp;
 #ifdef SYS_clone2
 	case SYS_clone2:
 #endif
-		if ((tcp->u_arg[arg0_index] & CLONE_PTRACE) == 0
-		    && (arg_setup (tcp, &state) < 0
-			|| set_arg0 (tcp, &state,
-				     tcp->u_arg[arg0_index] | CLONE_PTRACE) < 0
-			|| arg_finish_change (tcp, &state) < 0))
-			return -1;
+		/* ia64 calls directly `clone (CLONE_VFORK | CLONE_VM)'
+		   contrary to x86 SYS_vfork above.  Even on x86 we turn the
+		   vfork semantics into plain fork - each application must not
+		   depend on the vfork specifics according to POSIX.  We would
+		   hang waiting for the parent resume otherwise.  We need to
+		   clear also CLONE_VM but only in the CLONE_VFORK case as
+		   otherwise we would break pthread_create.  */
+
+		if ((arg_setup (tcp, &state) < 0
+		    || set_arg0 (tcp, &state,
+				 (tcp->u_arg[arg0_index] | CLONE_PTRACE)
+				 & ~(tcp->u_arg[arg0_index] & CLONE_VFORK
+				     ? CLONE_VFORK | CLONE_VM : 0)) < 0
+		    || arg_finish_change (tcp, &state) < 0))
+		    return -1;
 		tcp->flags |= TCB_BPTSET;
 		tcp->inst[0] = tcp->u_arg[arg0_index];
 		tcp->inst[1] = tcp->u_arg[arg1_index];
